Class: Aws::CleanRoomsML::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CleanRoomsML::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cleanroomsml/client.rb,
sig/client.rbs
Overview
An API client for CleanRoomsML. To construct a client, you need to configure a :region and :credentials.
client = Aws::CleanRoomsML::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAudienceModelResponseSuccess, _CreateConfiguredAudienceModelResponseSuccess, _CreateConfiguredModelAlgorithmAssociationResponseSuccess, _CreateConfiguredModelAlgorithmResponseSuccess, _CreateMLInputChannelResponseSuccess, _CreateTrainedModelResponseSuccess, _CreateTrainingDatasetResponseSuccess, _GetAudienceGenerationJobResponseSuccess, _GetAudienceModelResponseSuccess, _GetCollaborationConfiguredModelAlgorithmAssociationResponseSuccess, _GetCollaborationMLInputChannelResponseSuccess, _GetCollaborationTrainedModelResponseSuccess, _GetConfiguredAudienceModelPolicyResponseSuccess, _GetConfiguredAudienceModelResponseSuccess, _GetConfiguredModelAlgorithmAssociationResponseSuccess, _GetConfiguredModelAlgorithmResponseSuccess, _GetMLConfigurationResponseSuccess, _GetMLInputChannelResponseSuccess, _GetTrainedModelInferenceJobResponseSuccess, _GetTrainedModelResponseSuccess, _GetTrainingDatasetResponseSuccess, _ListAudienceExportJobsResponseSuccess, _ListAudienceGenerationJobsResponseSuccess, _ListAudienceModelsResponseSuccess, _ListCollaborationConfiguredModelAlgorithmAssociationsResponseSuccess, _ListCollaborationMLInputChannelsResponseSuccess, _ListCollaborationTrainedModelExportJobsResponseSuccess, _ListCollaborationTrainedModelInferenceJobsResponseSuccess, _ListCollaborationTrainedModelsResponseSuccess, _ListConfiguredAudienceModelsResponseSuccess, _ListConfiguredModelAlgorithmAssociationsResponseSuccess, _ListConfiguredModelAlgorithmsResponseSuccess, _ListMLInputChannelsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTrainedModelInferenceJobsResponseSuccess, _ListTrainedModelVersionsResponseSuccess, _ListTrainedModelsResponseSuccess, _ListTrainingDatasetsResponseSuccess, _PutConfiguredAudienceModelPolicyResponseSuccess, _StartAudienceGenerationJobResponseSuccess, _StartTrainedModelInferenceJobResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateConfiguredAudienceModelResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_trained_model(params = {}) ⇒ Struct
Submits a request to cancel the trained model job.
-
#cancel_trained_model_inference_job(params = {}) ⇒ Struct
Submits a request to cancel a trained model inference job.
-
#create_audience_model(params = {}) ⇒ Types::CreateAudienceModelResponse
Defines the information necessary to create an audience model.
-
#create_configured_audience_model(params = {}) ⇒ Types::CreateConfiguredAudienceModelResponse
Defines the information necessary to create a configured audience model.
-
#create_configured_model_algorithm(params = {}) ⇒ Types::CreateConfiguredModelAlgorithmResponse
Creates a configured model algorithm using a container image stored in an ECR repository.
-
#create_configured_model_algorithm_association(params = {}) ⇒ Types::CreateConfiguredModelAlgorithmAssociationResponse
Associates a configured model algorithm to a collaboration for use by any member of the collaboration.
-
#create_ml_input_channel(params = {}) ⇒ Types::CreateMLInputChannelResponse
Provides the information to create an ML input channel.
-
#create_trained_model(params = {}) ⇒ Types::CreateTrainedModelResponse
Creates a trained model from an associated configured model algorithm using data from any member of the collaboration.
-
#create_training_dataset(params = {}) ⇒ Types::CreateTrainingDatasetResponse
Defines the information necessary to create a training dataset.
-
#delete_audience_generation_job(params = {}) ⇒ Struct
Deletes the specified audience generation job, and removes all data associated with the job.
-
#delete_audience_model(params = {}) ⇒ Struct
Specifies an audience model that you want to delete.
-
#delete_configured_audience_model(params = {}) ⇒ Struct
Deletes the specified configured audience model.
-
#delete_configured_audience_model_policy(params = {}) ⇒ Struct
Deletes the specified configured audience model policy.
-
#delete_configured_model_algorithm(params = {}) ⇒ Struct
Deletes a configured model algorithm.
-
#delete_configured_model_algorithm_association(params = {}) ⇒ Struct
Deletes a configured model algorithm association.
-
#delete_ml_configuration(params = {}) ⇒ Struct
Deletes a ML modeling configuration.
-
#delete_ml_input_channel_data(params = {}) ⇒ Struct
Provides the information necessary to delete an ML input channel.
-
#delete_trained_model_output(params = {}) ⇒ Struct
Deletes the model artifacts stored by the service.
-
#delete_training_dataset(params = {}) ⇒ Struct
Specifies a training dataset that you want to delete.
-
#get_audience_generation_job(params = {}) ⇒ Types::GetAudienceGenerationJobResponse
Returns information about an audience generation job.
-
#get_audience_model(params = {}) ⇒ Types::GetAudienceModelResponse
Returns information about an audience model.
-
#get_collaboration_configured_model_algorithm_association(params = {}) ⇒ Types::GetCollaborationConfiguredModelAlgorithmAssociationResponse
Returns information about the configured model algorithm association in a collaboration.
-
#get_collaboration_ml_input_channel(params = {}) ⇒ Types::GetCollaborationMLInputChannelResponse
Returns information about a specific ML input channel in a collaboration.
-
#get_collaboration_trained_model(params = {}) ⇒ Types::GetCollaborationTrainedModelResponse
Returns information about a trained model in a collaboration.
-
#get_configured_audience_model(params = {}) ⇒ Types::GetConfiguredAudienceModelResponse
Returns information about a specified configured audience model.
-
#get_configured_audience_model_policy(params = {}) ⇒ Types::GetConfiguredAudienceModelPolicyResponse
Returns information about a configured audience model policy.
-
#get_configured_model_algorithm(params = {}) ⇒ Types::GetConfiguredModelAlgorithmResponse
Returns information about a configured model algorithm.
-
#get_configured_model_algorithm_association(params = {}) ⇒ Types::GetConfiguredModelAlgorithmAssociationResponse
Returns information about a configured model algorithm association.
-
#get_ml_configuration(params = {}) ⇒ Types::GetMLConfigurationResponse
Returns information about a specific ML configuration.
-
#get_ml_input_channel(params = {}) ⇒ Types::GetMLInputChannelResponse
Returns information about an ML input channel.
-
#get_trained_model(params = {}) ⇒ Types::GetTrainedModelResponse
Returns information about a trained model.
-
#get_trained_model_inference_job(params = {}) ⇒ Types::GetTrainedModelInferenceJobResponse
Returns information about a trained model inference job.
-
#get_training_dataset(params = {}) ⇒ Types::GetTrainingDatasetResponse
Returns information about a training dataset.
-
#list_audience_export_jobs(params = {}) ⇒ Types::ListAudienceExportJobsResponse
Returns a list of the audience export jobs.
-
#list_audience_generation_jobs(params = {}) ⇒ Types::ListAudienceGenerationJobsResponse
Returns a list of audience generation jobs.
-
#list_audience_models(params = {}) ⇒ Types::ListAudienceModelsResponse
Returns a list of audience models.
-
#list_collaboration_configured_model_algorithm_associations(params = {}) ⇒ Types::ListCollaborationConfiguredModelAlgorithmAssociationsResponse
Returns a list of the configured model algorithm associations in a collaboration.
-
#list_collaboration_ml_input_channels(params = {}) ⇒ Types::ListCollaborationMLInputChannelsResponse
Returns a list of the ML input channels in a collaboration.
-
#list_collaboration_trained_model_export_jobs(params = {}) ⇒ Types::ListCollaborationTrainedModelExportJobsResponse
Returns a list of the export jobs for a trained model in a collaboration.
-
#list_collaboration_trained_model_inference_jobs(params = {}) ⇒ Types::ListCollaborationTrainedModelInferenceJobsResponse
Returns a list of trained model inference jobs in a specified collaboration.
-
#list_collaboration_trained_models(params = {}) ⇒ Types::ListCollaborationTrainedModelsResponse
Returns a list of the trained models in a collaboration.
-
#list_configured_audience_models(params = {}) ⇒ Types::ListConfiguredAudienceModelsResponse
Returns a list of the configured audience models.
-
#list_configured_model_algorithm_associations(params = {}) ⇒ Types::ListConfiguredModelAlgorithmAssociationsResponse
Returns a list of configured model algorithm associations.
-
#list_configured_model_algorithms(params = {}) ⇒ Types::ListConfiguredModelAlgorithmsResponse
Returns a list of configured model algorithms.
-
#list_ml_input_channels(params = {}) ⇒ Types::ListMLInputChannelsResponse
Returns a list of ML input channels.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a provided resource.
-
#list_trained_model_inference_jobs(params = {}) ⇒ Types::ListTrainedModelInferenceJobsResponse
Returns a list of trained model inference jobs that match the request parameters.
-
#list_trained_model_versions(params = {}) ⇒ Types::ListTrainedModelVersionsResponse
Returns a list of trained model versions for a specified trained model.
-
#list_trained_models(params = {}) ⇒ Types::ListTrainedModelsResponse
Returns a list of trained models.
-
#list_training_datasets(params = {}) ⇒ Types::ListTrainingDatasetsResponse
Returns a list of training datasets.
-
#put_configured_audience_model_policy(params = {}) ⇒ Types::PutConfiguredAudienceModelPolicyResponse
Create or update the resource policy for a configured audience model.
-
#put_ml_configuration(params = {}) ⇒ Struct
Assigns information about an ML configuration.
-
#start_audience_export_job(params = {}) ⇒ Struct
Export an audience of a specified size after you have generated an audience.
-
#start_audience_generation_job(params = {}) ⇒ Types::StartAudienceGenerationJobResponse
Information necessary to start the audience generation job.
-
#start_trained_model_export_job(params = {}) ⇒ Struct
Provides the information necessary to start a trained model export job.
-
#start_trained_model_inference_job(params = {}) ⇒ Types::StartTrainedModelInferenceJobResponse
Defines the information necessary to begin a trained model inference job.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a specified resource.
-
#update_configured_audience_model(params = {}) ⇒ Types::UpdateConfiguredAudienceModelResponse
Provides the information necessary to update a configured audience model.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4162 4163 4164 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 4162 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4165 4166 4167 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 4165 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 4151 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 4135 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CleanRoomsML') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cleanroomsml' context[:gem_version] = '1.52.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_trained_model(params = {}) ⇒ Struct
Submits a request to cancel the trained model job.
82 |
# File 'sig/client.rbs', line 82 def cancel_trained_model: ( |
#cancel_trained_model_inference_job(params = {}) ⇒ Struct
Submits a request to cancel a trained model inference job.
90 |
# File 'sig/client.rbs', line 90 def cancel_trained_model_inference_job: ( |
#create_audience_model(params = {}) ⇒ Types::CreateAudienceModelResponse
Defines the information necessary to create an audience model. An audience model is a machine learning model that Clean Rooms ML trains to measure similarity between users. Clean Rooms ML manages training and storing the audience model. The audience model can be used in multiple calls to the StartAudienceGenerationJob API.
101 |
# File 'sig/client.rbs', line 101 def create_audience_model: ( |
#create_configured_audience_model(params = {}) ⇒ Types::CreateConfiguredAudienceModelResponse
Defines the information necessary to create a configured audience model.
117 |
# File 'sig/client.rbs', line 117 def create_configured_audience_model: ( |
#create_configured_model_algorithm(params = {}) ⇒ Types::CreateConfiguredModelAlgorithmResponse
Creates a configured model algorithm using a container image stored in an ECR repository.
138 |
# File 'sig/client.rbs', line 138 def create_configured_model_algorithm: ( |
#create_configured_model_algorithm_association(params = {}) ⇒ Types::CreateConfiguredModelAlgorithmAssociationResponse
Associates a configured model algorithm to a collaboration for use by any member of the collaboration.
166 |
# File 'sig/client.rbs', line 166 def create_configured_model_algorithm_association: ( |
#create_ml_input_channel(params = {}) ⇒ Types::CreateMLInputChannelResponse
Provides the information to create an ML input channel. An ML input channel is the result of a query that can be used for ML modeling.
212 |
# File 'sig/client.rbs', line 212 def create_ml_input_channel: ( |
#create_trained_model(params = {}) ⇒ Types::CreateTrainedModelResponse
Creates a trained model from an associated configured model algorithm using data from any member of the collaboration.
247 |
# File 'sig/client.rbs', line 247 def create_trained_model: ( |
#create_training_dataset(params = {}) ⇒ Types::CreateTrainingDatasetResponse
Defines the information necessary to create a training dataset. In
Clean Rooms ML, the TrainingDataset is metadata that points to a
Glue table, which is read only during AudienceModel creation.
288 |
# File 'sig/client.rbs', line 288 def create_training_dataset: ( |
#delete_audience_generation_job(params = {}) ⇒ Struct
Deletes the specified audience generation job, and removes all data associated with the job.
317 |
# File 'sig/client.rbs', line 317 def delete_audience_generation_job: ( |
#delete_audience_model(params = {}) ⇒ Struct
Specifies an audience model that you want to delete. You can't delete an audience model if there are any configured audience models that depend on the audience model.
323 |
# File 'sig/client.rbs', line 323 def delete_audience_model: ( |
#delete_configured_audience_model(params = {}) ⇒ Struct
Deletes the specified configured audience model. You can't delete a configured audience model if there are any lookalike models that use the configured audience model. If you delete a configured audience model, it will be removed from any collaborations that it is associated to.
329 |
# File 'sig/client.rbs', line 329 def delete_configured_audience_model: ( |
#delete_configured_audience_model_policy(params = {}) ⇒ Struct
Deletes the specified configured audience model policy.
335 |
# File 'sig/client.rbs', line 335 def delete_configured_audience_model_policy: ( |
#delete_configured_model_algorithm(params = {}) ⇒ Struct
Deletes a configured model algorithm.
341 |
# File 'sig/client.rbs', line 341 def delete_configured_model_algorithm: ( |
#delete_configured_model_algorithm_association(params = {}) ⇒ Struct
Deletes a configured model algorithm association.
347 |
# File 'sig/client.rbs', line 347 def delete_configured_model_algorithm_association: ( |
#delete_ml_configuration(params = {}) ⇒ Struct
Deletes a ML modeling configuration.
354 |
# File 'sig/client.rbs', line 354 def delete_ml_configuration: ( |
#delete_ml_input_channel_data(params = {}) ⇒ Struct
Provides the information necessary to delete an ML input channel.
360 |
# File 'sig/client.rbs', line 360 def delete_ml_input_channel_data: ( |
#delete_trained_model_output(params = {}) ⇒ Struct
Deletes the model artifacts stored by the service.
367 |
# File 'sig/client.rbs', line 367 def delete_trained_model_output: ( |
#delete_training_dataset(params = {}) ⇒ Struct
Specifies a training dataset that you want to delete. You can't
delete a training dataset if there are any audience models that depend
on the training dataset. In Clean Rooms ML, the TrainingDataset is
metadata that points to a Glue table, which is read only during
AudienceModel creation. This action deletes the metadata.
375 |
# File 'sig/client.rbs', line 375 def delete_training_dataset: ( |
#get_audience_generation_job(params = {}) ⇒ Types::GetAudienceGenerationJobResponse
Returns information about an audience generation job.
399 |
# File 'sig/client.rbs', line 399 def get_audience_generation_job: ( |
#get_audience_model(params = {}) ⇒ Types::GetAudienceModelResponse
Returns information about an audience model
420 |
# File 'sig/client.rbs', line 420 def get_audience_model: ( |
#get_collaboration_configured_model_algorithm_association(params = {}) ⇒ Types::GetCollaborationConfiguredModelAlgorithmAssociationResponse
Returns information about the configured model algorithm association in a collaboration.
439 |
# File 'sig/client.rbs', line 439 def get_collaboration_configured_model_algorithm_association: ( |
#get_collaboration_ml_input_channel(params = {}) ⇒ Types::GetCollaborationMLInputChannelResponse
Returns information about a specific ML input channel in a collaboration.
465 |
# File 'sig/client.rbs', line 465 def get_collaboration_ml_input_channel: ( |
#get_collaboration_trained_model(params = {}) ⇒ Types::GetCollaborationTrainedModelResponse
Returns information about a trained model in a collaboration.
497 |
# File 'sig/client.rbs', line 497 def get_collaboration_trained_model: ( |
#get_configured_audience_model(params = {}) ⇒ Types::GetConfiguredAudienceModelResponse
Returns information about a specified configured audience model.
521 |
# File 'sig/client.rbs', line 521 def get_configured_audience_model: ( |
#get_configured_audience_model_policy(params = {}) ⇒ Types::GetConfiguredAudienceModelPolicyResponse
Returns information about a configured audience model policy.
533 |
# File 'sig/client.rbs', line 533 def get_configured_audience_model_policy: ( |
#get_configured_model_algorithm(params = {}) ⇒ Types::GetConfiguredModelAlgorithmResponse
Returns information about a configured model algorithm.
552 |
# File 'sig/client.rbs', line 552 def get_configured_model_algorithm: ( |
#get_configured_model_algorithm_association(params = {}) ⇒ Types::GetConfiguredModelAlgorithmAssociationResponse
Returns information about a configured model algorithm association.
571 |
# File 'sig/client.rbs', line 571 def get_configured_model_algorithm_association: ( |
#get_ml_configuration(params = {}) ⇒ Types::GetMLConfigurationResponse
Returns information about a specific ML configuration.
585 |
# File 'sig/client.rbs', line 585 def get_ml_configuration: ( |
#get_ml_input_channel(params = {}) ⇒ Types::GetMLInputChannelResponse
Returns information about an ML input channel.
615 |
# File 'sig/client.rbs', line 615 def get_ml_input_channel: ( |
#get_trained_model(params = {}) ⇒ Types::GetTrainedModelResponse
Returns information about a trained model.
651 |
# File 'sig/client.rbs', line 651 def get_trained_model: ( |
#get_trained_model_inference_job(params = {}) ⇒ Types::GetTrainedModelInferenceJobResponse
Returns information about a trained model inference job.
686 |
# File 'sig/client.rbs', line 686 def get_trained_model_inference_job: ( |
#get_training_dataset(params = {}) ⇒ Types::GetTrainingDatasetResponse
Returns information about a training dataset.
705 |
# File 'sig/client.rbs', line 705 def get_training_dataset: ( |
#list_audience_export_jobs(params = {}) ⇒ Types::ListAudienceExportJobsResponse
Returns a list of the audience export jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
716 |
# File 'sig/client.rbs', line 716 def list_audience_export_jobs: ( |
#list_audience_generation_jobs(params = {}) ⇒ Types::ListAudienceGenerationJobsResponse
Returns a list of audience generation jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
729 |
# File 'sig/client.rbs', line 729 def list_audience_generation_jobs: ( |
#list_audience_models(params = {}) ⇒ Types::ListAudienceModelsResponse
Returns a list of audience models.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
743 |
# File 'sig/client.rbs', line 743 def list_audience_models: ( |
#list_collaboration_configured_model_algorithm_associations(params = {}) ⇒ Types::ListCollaborationConfiguredModelAlgorithmAssociationsResponse
Returns a list of the configured model algorithm associations in a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
755 |
# File 'sig/client.rbs', line 755 def list_collaboration_configured_model_algorithm_associations: ( |
#list_collaboration_ml_input_channels(params = {}) ⇒ Types::ListCollaborationMLInputChannelsResponse
Returns a list of the ML input channels in a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
768 |
# File 'sig/client.rbs', line 768 def list_collaboration_ml_input_channels: ( |
#list_collaboration_trained_model_export_jobs(params = {}) ⇒ Types::ListCollaborationTrainedModelExportJobsResponse
Returns a list of the export jobs for a trained model in a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
781 |
# File 'sig/client.rbs', line 781 def list_collaboration_trained_model_export_jobs: ( |
#list_collaboration_trained_model_inference_jobs(params = {}) ⇒ Types::ListCollaborationTrainedModelInferenceJobsResponse
Returns a list of trained model inference jobs in a specified collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
796 |
# File 'sig/client.rbs', line 796 def list_collaboration_trained_model_inference_jobs: ( |
#list_collaboration_trained_models(params = {}) ⇒ Types::ListCollaborationTrainedModelsResponse
Returns a list of the trained models in a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
811 |
# File 'sig/client.rbs', line 811 def list_collaboration_trained_models: ( |
#list_configured_audience_models(params = {}) ⇒ Types::ListConfiguredAudienceModelsResponse
Returns a list of the configured audience models.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
824 |
# File 'sig/client.rbs', line 824 def list_configured_audience_models: ( |
#list_configured_model_algorithm_associations(params = {}) ⇒ Types::ListConfiguredModelAlgorithmAssociationsResponse
Returns a list of configured model algorithm associations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
836 |
# File 'sig/client.rbs', line 836 def list_configured_model_algorithm_associations: ( |
#list_configured_model_algorithms(params = {}) ⇒ Types::ListConfiguredModelAlgorithmsResponse
Returns a list of configured model algorithms.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
849 |
# File 'sig/client.rbs', line 849 def list_configured_model_algorithms: ( |
#list_ml_input_channels(params = {}) ⇒ Types::ListMLInputChannelsResponse
Returns a list of ML input channels.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
861 |
# File 'sig/client.rbs', line 861 def list_ml_input_channels: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a provided resource.
873 |
# File 'sig/client.rbs', line 873 def list_tags_for_resource: ( |
#list_trained_model_inference_jobs(params = {}) ⇒ Types::ListTrainedModelInferenceJobsResponse
Returns a list of trained model inference jobs that match the request parameters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
884 |
# File 'sig/client.rbs', line 884 def list_trained_model_inference_jobs: ( |
#list_trained_model_versions(params = {}) ⇒ Types::ListTrainedModelVersionsResponse
Returns a list of trained model versions for a specified trained model. This operation allows you to view all versions of a trained model, including information about their status and creation details. You can use this to track the evolution of your trained models and select specific versions for inference or further training.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
899 |
# File 'sig/client.rbs', line 899 def list_trained_model_versions: ( |
#list_trained_models(params = {}) ⇒ Types::ListTrainedModelsResponse
Returns a list of trained models.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
914 |
# File 'sig/client.rbs', line 914 def list_trained_models: ( |
#list_training_datasets(params = {}) ⇒ Types::ListTrainingDatasetsResponse
Returns a list of training datasets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
927 |
# File 'sig/client.rbs', line 927 def list_training_datasets: ( |
#put_configured_audience_model_policy(params = {}) ⇒ Types::PutConfiguredAudienceModelPolicyResponse
Create or update the resource policy for a configured audience model.
939 |
# File 'sig/client.rbs', line 939 def put_configured_audience_model_policy: ( |
#put_ml_configuration(params = {}) ⇒ Struct
Assigns information about an ML configuration.
948 |
# File 'sig/client.rbs', line 948 def put_ml_configuration: ( |
#start_audience_export_job(params = {}) ⇒ Struct
Export an audience of a specified size after you have generated an audience.
962 |
# File 'sig/client.rbs', line 962 def start_audience_export_job: ( |
#start_audience_generation_job(params = {}) ⇒ Types::StartAudienceGenerationJobResponse
Information necessary to start the audience generation job.
978 |
# File 'sig/client.rbs', line 978 def start_audience_generation_job: ( |
#start_trained_model_export_job(params = {}) ⇒ Struct
Provides the information necessary to start a trained model export job.
1001 |
# File 'sig/client.rbs', line 1001 def start_trained_model_export_job: ( |
#start_trained_model_inference_job(params = {}) ⇒ Types::StartTrainedModelInferenceJobResponse
Defines the information necessary to begin a trained model inference job.
1022 |
# File 'sig/client.rbs', line 1022 def start_trained_model_inference_job: ( |
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a specified resource.
1058 |
# File 'sig/client.rbs', line 1058 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a specified resource.
1068 |
# File 'sig/client.rbs', line 1068 def untag_resource: ( |
#update_configured_audience_model(params = {}) ⇒ Types::UpdateConfiguredAudienceModelResponse
Provides the information necessary to update a configured audience model. Updates that impact audience generation jobs take effect when a new job starts, but do not impact currently running jobs.
1079 |
# File 'sig/client.rbs', line 1079 def update_configured_audience_model: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4155 4156 4157 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 4155 def waiter_names [] end |