Class: Aws::CleanRoomsML::Types::CollaborationTrainedModelSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::CollaborationTrainedModelSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Provides summary information about a trained model in a collaboration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#collaboration_identifier ⇒ String
The collaboration ID of the collaboration that contains the trained model.
-
#configured_model_algorithm_association_arn ⇒ String
The Amazon Resource Name (ARN) of the configured model algorithm association that is used for this trained model.
-
#create_time ⇒ Time
The time at which the trained model was created.
-
#creator_account_id ⇒ String
The account ID of the member that created the trained model.
-
#description ⇒ String
The description of the trained model.
-
#incremental_training_data_channels ⇒ Array<Types::IncrementalTrainingDataChannelOutput>
Information about the incremental training data channels used to create this version of the trained model.
-
#membership_identifier ⇒ String
The membership ID of the member that created the trained model.
-
#ml_model_training_payer_account_id ⇒ String
The account ID of the member that is responsible for paying for model training costs.
-
#name ⇒ String
The name of the trained model.
-
#status ⇒ String
The status of the trained model.
-
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model.
-
#update_time ⇒ Time
The most recent time at which the trained model was updated.
-
#version_identifier ⇒ String
The version identifier of this trained model version.
Instance Attribute Details
#collaboration_identifier ⇒ String
The collaboration ID of the collaboration that contains the trained model.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#configured_model_algorithm_association_arn ⇒ String
The Amazon Resource Name (ARN) of the configured model algorithm association that is used for this trained model.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the trained model was created.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#creator_account_id ⇒ String
The account ID of the member that created the trained model.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the trained model.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#incremental_training_data_channels ⇒ Array<Types::IncrementalTrainingDataChannelOutput>
Information about the incremental training data channels used to create this version of the trained model.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The membership ID of the member that created the trained model.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#ml_model_training_payer_account_id ⇒ String
The account ID of the member that is responsible for paying for model training costs.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the trained model.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the trained model.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the trained model was updated.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |
#version_identifier ⇒ String
The version identifier of this trained model version.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 806 class CollaborationTrainedModelSummary < Struct.new( :create_time, :update_time, :trained_model_arn, :name, :version_identifier, :incremental_training_data_channels, :description, :membership_identifier, :collaboration_identifier, :status, :configured_model_algorithm_association_arn, :creator_account_id, :ml_model_training_payer_account_id) SENSITIVE = [] include Aws::Structure end |