Class: Aws::CleanRoomsML::Types::ConfiguredAudienceModelSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::ConfiguredAudienceModelSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Information about the configured audience model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the audience model that was used to create the configured audience model.
-
#configured_audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the configured audience model that you are interested in.
-
#create_time ⇒ Time
The time at which the configured audience model was created.
-
#description ⇒ String
The description of the configured audience model.
-
#name ⇒ String
The name of the configured audience model.
-
#output_config ⇒ Types::ConfiguredAudienceModelOutputConfig
The output configuration of the configured audience model.
-
#status ⇒ String
The status of the configured audience model.
-
#update_time ⇒ Time
The most recent time at which the configured audience model was updated.
Instance Attribute Details
#audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the audience model that was used to create the configured audience model.
945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 945 class ConfiguredAudienceModelSummary < Struct.new( :create_time, :update_time, :name, :audience_model_arn, :output_config, :description, :configured_audience_model_arn, :status) SENSITIVE = [] include Aws::Structure end |
#configured_audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the configured audience model that you are interested in.
945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 945 class ConfiguredAudienceModelSummary < Struct.new( :create_time, :update_time, :name, :audience_model_arn, :output_config, :description, :configured_audience_model_arn, :status) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the configured audience model was created.
945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 945 class ConfiguredAudienceModelSummary < Struct.new( :create_time, :update_time, :name, :audience_model_arn, :output_config, :description, :configured_audience_model_arn, :status) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the configured audience model.
945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 945 class ConfiguredAudienceModelSummary < Struct.new( :create_time, :update_time, :name, :audience_model_arn, :output_config, :description, :configured_audience_model_arn, :status) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configured audience model.
945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 945 class ConfiguredAudienceModelSummary < Struct.new( :create_time, :update_time, :name, :audience_model_arn, :output_config, :description, :configured_audience_model_arn, :status) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::ConfiguredAudienceModelOutputConfig
The output configuration of the configured audience model.
945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 945 class ConfiguredAudienceModelSummary < Struct.new( :create_time, :update_time, :name, :audience_model_arn, :output_config, :description, :configured_audience_model_arn, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the configured audience model.
945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 945 class ConfiguredAudienceModelSummary < Struct.new( :create_time, :update_time, :name, :audience_model_arn, :output_config, :description, :configured_audience_model_arn, :status) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the configured audience model was updated.
945 946 947 948 949 950 951 952 953 954 955 956 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 945 class ConfiguredAudienceModelSummary < Struct.new( :create_time, :update_time, :name, :audience_model_arn, :output_config, :description, :configured_audience_model_arn, :status) SENSITIVE = [] include Aws::Structure end |