Class: Aws::CleanRoomsML::Types::ConfiguredModelAlgorithmSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::ConfiguredModelAlgorithmSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Provides summary information about a configured model algorithm.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configured_model_algorithm_arn ⇒ String
The Amazon Resource Name (ARN) of the configured model algorithm.
-
#create_time ⇒ Time
The time at which the configured model algorithm was created.
-
#description ⇒ String
The description of the configured model algorithm.
-
#name ⇒ String
The name of the configured model algorithm.
-
#update_time ⇒ Time
The most recent time at which the configured model algorithm was updated.
Instance Attribute Details
#configured_model_algorithm_arn ⇒ String
The Amazon Resource Name (ARN) of the configured model algorithm.
1039 1040 1041 1042 1043 1044 1045 1046 1047 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1039 class ConfiguredModelAlgorithmSummary < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :description) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the configured model algorithm was created.
1039 1040 1041 1042 1043 1044 1045 1046 1047 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1039 class ConfiguredModelAlgorithmSummary < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the configured model algorithm.
1039 1040 1041 1042 1043 1044 1045 1046 1047 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1039 class ConfiguredModelAlgorithmSummary < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configured model algorithm.
1039 1040 1041 1042 1043 1044 1045 1046 1047 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1039 class ConfiguredModelAlgorithmSummary < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :description) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the configured model algorithm was updated.
1039 1040 1041 1042 1043 1044 1045 1046 1047 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1039 class ConfiguredModelAlgorithmSummary < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :description) SENSITIVE = [] include Aws::Structure end |