Class: Aws::CleanRoomsML::Types::ContainerConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Provides configuration information for the dockerized container where the model algorithm is stored.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#argumentsArray<String>

The arguments for a container used to run a training job. See How Amazon SageMaker Runs Your Training Image for additional information. For more information, see [How Sagemaker runs your training image].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-training-algo-dockerfile.html

Returns:

  • (Array<String>)


1111
1112
1113
1114
1115
1116
1117
1118
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1111

class ContainerConfig < Struct.new(
  :image_uri,
  :entrypoint,
  :arguments,
  :metric_definitions)
  SENSITIVE = []
  include Aws::Structure
end

#entrypointArray<String>

The entrypoint script for a Docker container used to run a training job. This script takes precedence over the default train processing instructions. See How Amazon SageMaker Runs Your Training Image for additional information. For more information, see [How Sagemaker runs your training image].

[1]: docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-training-algo-dockerfile.html

Returns:

  • (Array<String>)


1111
1112
1113
1114
1115
1116
1117
1118
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1111

class ContainerConfig < Struct.new(
  :image_uri,
  :entrypoint,
  :arguments,
  :metric_definitions)
  SENSITIVE = []
  include Aws::Structure
end

#image_uriString

The registry path of the docker image that contains the algorithm. Clean Rooms ML currently only supports the ‘registry/repository` image path format. For more information about using images in Clean Rooms ML, see the [Sagemaker API reference].

[1]: docs.aws.amazon.com/sagemaker/latest/APIReference/API_AlgorithmSpecification.html#sagemaker-Type-AlgorithmSpecification-TrainingImage

Returns:

  • (String)


1111
1112
1113
1114
1115
1116
1117
1118
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1111

class ContainerConfig < Struct.new(
  :image_uri,
  :entrypoint,
  :arguments,
  :metric_definitions)
  SENSITIVE = []
  include Aws::Structure
end

#metric_definitionsArray<Types::MetricDefinition>

A list of metric definition objects. Each object specifies the metric name and regular expressions used to parse algorithm logs. Amazon Web Services Clean Rooms ML publishes each metric to all members’ Amazon CloudWatch using IAM role configured in PutMLConfiguration.

Returns:



1111
1112
1113
1114
1115
1116
1117
1118
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1111

class ContainerConfig < Struct.new(
  :image_uri,
  :entrypoint,
  :arguments,
  :metric_definitions)
  SENSITIVE = []
  include Aws::Structure
end