Class: Aws::CleanRoomsML::Types::CreateAudienceModelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the audience model.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1165

class CreateAudienceModelRequest < Struct.new(
  :training_data_start_time,
  :training_data_end_time,
  :name,
  :training_dataset_arn,
  :kms_key_arn,
  :tags,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the KMS key. This key is used to encrypt and decrypt customer-owned data in the trained ML model and the associated data.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1165

class CreateAudienceModelRequest < Struct.new(
  :training_data_start_time,
  :training_data_end_time,
  :name,
  :training_dataset_arn,
  :kms_key_arn,
  :tags,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the audience model resource.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1165

class CreateAudienceModelRequest < Struct.new(
  :training_data_start_time,
  :training_data_end_time,
  :name,
  :training_dataset_arn,
  :kms_key_arn,
  :tags,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The optional metadata that you apply to the resource to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define.

The following basic restrictions apply to tags:

  • Maximum number of tags per resource - 50.

  • For each resource, each tag key must be unique, and each tag key can have only one value.

  • Maximum key length - 128 Unicode characters in UTF-8.

  • Maximum value length - 256 Unicode characters in UTF-8.

  • If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.

  • Tag keys and values are case sensitive.

  • Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Clean Rooms ML considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1165

class CreateAudienceModelRequest < Struct.new(
  :training_data_start_time,
  :training_data_end_time,
  :name,
  :training_dataset_arn,
  :kms_key_arn,
  :tags,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#training_data_end_timeTime

The end date and time of the training window.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1165

class CreateAudienceModelRequest < Struct.new(
  :training_data_start_time,
  :training_data_end_time,
  :name,
  :training_dataset_arn,
  :kms_key_arn,
  :tags,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#training_data_start_timeTime

The start date and time of the training window.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1165

class CreateAudienceModelRequest < Struct.new(
  :training_data_start_time,
  :training_data_end_time,
  :name,
  :training_dataset_arn,
  :kms_key_arn,
  :tags,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#training_dataset_arnString

The Amazon Resource Name (ARN) of the training dataset for this audience model.



1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1165

class CreateAudienceModelRequest < Struct.new(
  :training_data_start_time,
  :training_data_end_time,
  :name,
  :training_dataset_arn,
  :kms_key_arn,
  :tags,
  :description)
  SENSITIVE = []
  include Aws::Structure
end