Class: Aws::CleanRoomsML::Types::CreateConfiguredModelAlgorithmAssociationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configured_model_algorithm_arnString

The Amazon Resource Name (ARN) of the configured model algorithm that you want to associate.

Returns:



1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1382

class CreateConfiguredModelAlgorithmAssociationRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_arn,
  :name,
  :description,
  :privacy_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the configured model algorithm association.

Returns:



1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1382

class CreateConfiguredModelAlgorithmAssociationRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_arn,
  :name,
  :description,
  :privacy_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The membership ID of the member who is associating this configured model algorithm.

Returns:



1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1382

class CreateConfiguredModelAlgorithmAssociationRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_arn,
  :name,
  :description,
  :privacy_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the configured model algorithm association.

Returns:



1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1382

class CreateConfiguredModelAlgorithmAssociationRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_arn,
  :name,
  :description,
  :privacy_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#privacy_configurationTypes::PrivacyConfiguration

Specifies the privacy configuration information for the configured model algorithm association. This information includes the maximum data size that can be exported.

Returns:



1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1382

class CreateConfiguredModelAlgorithmAssociationRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_arn,
  :name,
  :description,
  :privacy_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The optional metadata that you apply to the resource to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define.

The following basic restrictions apply to tags:

  • Maximum number of tags per resource - 50.

  • For each resource, each tag key must be unique, and each tag key can have only one value.

  • Maximum key length - 128 Unicode characters in UTF-8.

  • Maximum value length - 256 Unicode characters in UTF-8.

  • If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.

  • Tag keys and values are case sensitive.

  • Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Clean Rooms ML considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.

Returns:



1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1382

class CreateConfiguredModelAlgorithmAssociationRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_arn,
  :name,
  :description,
  :privacy_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end