Class: Aws::CleanRoomsML::Types::CreateConfiguredModelAlgorithmRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the configured model algorithm.



1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1453

class CreateConfiguredModelAlgorithmRequest < Struct.new(
  :name,
  :description,
  :role_arn,
  :training_container_config,
  :inference_container_config,
  :tags,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#inference_container_configTypes::InferenceContainerConfig

Configuration information for the inference container that is used when you run an inference job on a configured model algorithm.



1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1453

class CreateConfiguredModelAlgorithmRequest < Struct.new(
  :name,
  :description,
  :role_arn,
  :training_container_config,
  :inference_container_config,
  :tags,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the KMS key. This key is used to encrypt and decrypt customer-owned data in the configured ML model algorithm and associated data.



1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1453

class CreateConfiguredModelAlgorithmRequest < Struct.new(
  :name,
  :description,
  :role_arn,
  :training_container_config,
  :inference_container_config,
  :tags,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the configured model algorithm.



1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1453

class CreateConfiguredModelAlgorithmRequest < Struct.new(
  :name,
  :description,
  :role_arn,
  :training_container_config,
  :inference_container_config,
  :tags,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the role that is used to access the repository.



1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1453

class CreateConfiguredModelAlgorithmRequest < Struct.new(
  :name,
  :description,
  :role_arn,
  :training_container_config,
  :inference_container_config,
  :tags,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The optional metadata that you apply to the resource to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define.

The following basic restrictions apply to tags:

  • Maximum number of tags per resource - 50.

  • For each resource, each tag key must be unique, and each tag key can have only one value.

  • Maximum key length - 128 Unicode characters in UTF-8.

  • Maximum value length - 256 Unicode characters in UTF-8.

  • If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.

  • Tag keys and values are case sensitive.

  • Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Clean Rooms ML considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.



1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1453

class CreateConfiguredModelAlgorithmRequest < Struct.new(
  :name,
  :description,
  :role_arn,
  :training_container_config,
  :inference_container_config,
  :tags,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#training_container_configTypes::ContainerConfig

Configuration information for the training container, including entrypoints and arguments.



1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1453

class CreateConfiguredModelAlgorithmRequest < Struct.new(
  :name,
  :description,
  :role_arn,
  :training_container_config,
  :inference_container_config,
  :tags,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end