Class: Aws::CleanRoomsML::Types::CreateMLInputChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configured_model_algorithm_associationsArray<String>

The associated configured model algorithms that are necessary to create this ML input channel.



1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1544

class CreateMLInputChannelRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_associations,
  :input_channel,
  :name,
  :retention_in_days,
  :description,
  :kms_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the ML input channel.



1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1544

class CreateMLInputChannelRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_associations,
  :input_channel,
  :name,
  :retention_in_days,
  :description,
  :kms_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#input_channelTypes::InputChannel

The input data that is used to create this ML input channel.



1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1544

class CreateMLInputChannelRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_associations,
  :input_channel,
  :name,
  :retention_in_days,
  :description,
  :kms_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the KMS key that is used to access the input channel.



1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1544

class CreateMLInputChannelRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_associations,
  :input_channel,
  :name,
  :retention_in_days,
  :description,
  :kms_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The membership ID of the member that is creating the ML input channel.



1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1544

class CreateMLInputChannelRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_associations,
  :input_channel,
  :name,
  :retention_in_days,
  :description,
  :kms_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the ML input channel.



1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1544

class CreateMLInputChannelRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_associations,
  :input_channel,
  :name,
  :retention_in_days,
  :description,
  :kms_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#retention_in_daysInteger

The number of days that the data in the ML input channel is retained.



1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1544

class CreateMLInputChannelRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_associations,
  :input_channel,
  :name,
  :retention_in_days,
  :description,
  :kms_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The optional metadata that you apply to the resource to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define.

The following basic restrictions apply to tags:

  • Maximum number of tags per resource - 50.

  • For each resource, each tag key must be unique, and each tag key can have only one value.

  • Maximum key length - 128 Unicode characters in UTF-8.

  • Maximum value length - 256 Unicode characters in UTF-8.

  • If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.

  • Tag keys and values are case sensitive.

  • Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Clean Rooms ML considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.



1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1544

class CreateMLInputChannelRequest < Struct.new(
  :membership_identifier,
  :configured_model_algorithm_associations,
  :input_channel,
  :name,
  :retention_in_days,
  :description,
  :kms_key_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end