Class: Aws::CleanRoomsML::Types::CreateTrainedModelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configured_model_algorithm_association_arnString

The associated configured model algorithm used to train this model.

Returns:

  • (String)


1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#data_channelsArray<Types::ModelTrainingDataChannel>

Defines the data channels that are used as input for the trained model request.

Limit: Maximum of 20 channels total (including both ‘dataChannels` and `incrementalTrainingDataChannels`).



1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the trained model.

Returns:

  • (String)


1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#environmentHash<String,String>

The environment variables to set in the Docker container.

Returns:

  • (Hash<String,String>)


1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#hyperparametersHash<String,String>

Algorithm-specific parameters that influence the quality of the model. You set hyperparameters before you start the learning process.

Returns:

  • (Hash<String,String>)


1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#incremental_training_data_channelsArray<Types::IncrementalTrainingDataChannel>

Specifies the incremental training data channels for the trained model.

Incremental training allows you to create a new trained model with updates without retraining from scratch. You can specify up to one incremental training data channel that references a previously trained model and its version.

Limit: Maximum of 20 channels total (including both ‘incrementalTrainingDataChannels` and `dataChannels`).



1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Amazon Resource Name (ARN) of the KMS key. This key is used to encrypt and decrypt customer-owned data in the trained ML model and the associated data.

Returns:

  • (String)


1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The membership ID of the member that is creating the trained model.

Returns:

  • (String)


1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#ml_model_training_payer_account_idString

The account ID of the member that is responsible for paying for model training costs.

Returns:

  • (String)


1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the trained model.

Returns:

  • (String)


1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_configTypes::ResourceConfig

Information about the EC2 resources that are used to train this model.



1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#stopping_conditionTypes::StoppingCondition

The criteria that is used to stop model training.



1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The optional metadata that you apply to the resource to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define.

The following basic restrictions apply to tags:

  • Maximum number of tags per resource - 50.

  • For each resource, each tag key must be unique, and each tag key can have only one value.

  • Maximum key length - 128 Unicode characters in UTF-8.

  • Maximum value length - 256 Unicode characters in UTF-8.

  • If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.

  • Tag keys and values are case sensitive.

  • Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Clean Rooms ML considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.

Returns:

  • (Hash<String,String>)


1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#training_input_modeString

The input mode for accessing the training data. This parameter determines how the training data is made available to the training algorithm. Valid values are:

  • ‘File` - The training data is downloaded to the training instance and made available as files.

  • ‘FastFile` - The training data is streamed directly from Amazon S3 to the training algorithm, providing faster access for large datasets.

  • ‘Pipe` - The training data is streamed to the training algorithm using named pipes, which can improve performance for certain algorithms.

Returns:

  • (String)


1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 1711

class CreateTrainedModelRequest < Struct.new(
  :membership_identifier,
  :name,
  :configured_model_algorithm_association_arn,
  :hyperparameters,
  :environment,
  :resource_config,
  :stopping_condition,
  :incremental_training_data_channels,
  :data_channels,
  :training_input_mode,
  :description,
  :kms_key_arn,
  :tags,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end