Class: Aws::CleanRoomsML::Types::DeleteTrainedModelOutputRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::DeleteTrainedModelOutputRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#membership_identifier ⇒ String
The membership ID of the member that is deleting the trained model output.
-
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model whose output you want to delete.
-
#version_identifier ⇒ String
The version identifier of the trained model to delete.
Instance Attribute Details
#membership_identifier ⇒ String
The membership ID of the member that is deleting the trained model output.
2061 2062 2063 2064 2065 2066 2067 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2061 class DeleteTrainedModelOutputRequest < Struct.new( :trained_model_arn, :membership_identifier, :version_identifier) SENSITIVE = [] include Aws::Structure end |
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model whose output you want to delete.
2061 2062 2063 2064 2065 2066 2067 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2061 class DeleteTrainedModelOutputRequest < Struct.new( :trained_model_arn, :membership_identifier, :version_identifier) SENSITIVE = [] include Aws::Structure end |
#version_identifier ⇒ String
The version identifier of the trained model to delete. If not specified, the operation will delete the base version of the trained model. When specified, only the particular version will be deleted.
2061 2062 2063 2064 2065 2066 2067 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2061 class DeleteTrainedModelOutputRequest < Struct.new( :trained_model_arn, :membership_identifier, :version_identifier) SENSITIVE = [] include Aws::Structure end |