Class: Aws::CleanRoomsML::Types::GetCollaborationMLInputChannelResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#collaboration_identifierString

The collaboration ID of the collaboration that contains the ML input channel.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#configured_model_algorithm_associationsArray<String>

The configured model algorithm associations that were used to create the ML input channel.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time at which the ML input channel was created.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#creator_account_idString

The account ID of the member who created the ML input channel.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the ML input channel.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The membership ID of the membership that contains the ML input channel.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#ml_input_channel_arnString

The Amazon Resource Name (ARN) of the ML input channel.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the ML input channel.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_recordsInteger

The number of records in the ML input channel.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#payer_configurationTypes::PayerConfiguration

The payer configuration for the ML input channel.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#privacy_budgetsTypes::PrivacyBudgets

Returns the privacy budgets that control access to this Clean Rooms ML input channel. Use these budgets to monitor and limit resource consumption over specified time periods.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#retention_in_daysInteger

The number of days to retain the data for the ML input channel.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the ML input channel.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#status_detailsTypes::StatusDetails

Details about the status of a resource.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#synthetic_data_configurationTypes::SyntheticDataConfiguration

The synthetic data configuration for this ML input channel, including parameters for generating privacy-preserving synthetic data and evaluation scores for measuring the privacy of the generated data.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The most recent time at which the ML input channel was updated.

Returns:



2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
2482
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2463

class GetCollaborationMLInputChannelResponse < Struct.new(
  :membership_identifier,
  :collaboration_identifier,
  :ml_input_channel_arn,
  :name,
  :configured_model_algorithm_associations,
  :status,
  :status_details,
  :retention_in_days,
  :number_of_records,
  :privacy_budgets,
  :description,
  :synthetic_data_configuration,
  :payer_configuration,
  :create_time,
  :update_time,
  :creator_account_id)
  SENSITIVE = []
  include Aws::Structure
end