Class: Aws::CleanRoomsML::Types::GetCollaborationTrainedModelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::GetCollaborationTrainedModelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#collaboration_identifier ⇒ String
The collaboration ID that contains the trained model that you want to return information about.
-
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model that you want to return information about.
-
#version_identifier ⇒ String
The version identifier of the trained model to retrieve.
Instance Attribute Details
#collaboration_identifier ⇒ String
The collaboration ID that contains the trained model that you want to return information about.
2468 2469 2470 2471 2472 2473 2474 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2468 class GetCollaborationTrainedModelRequest < Struct.new( :trained_model_arn, :collaboration_identifier, :version_identifier) SENSITIVE = [] include Aws::Structure end |
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model that you want to return information about.
2468 2469 2470 2471 2472 2473 2474 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2468 class GetCollaborationTrainedModelRequest < Struct.new( :trained_model_arn, :collaboration_identifier, :version_identifier) SENSITIVE = [] include Aws::Structure end |
#version_identifier ⇒ String
The version identifier of the trained model to retrieve. If not specified, the operation returns information about the latest version of the trained model.
2468 2469 2470 2471 2472 2473 2474 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2468 class GetCollaborationTrainedModelRequest < Struct.new( :trained_model_arn, :collaboration_identifier, :version_identifier) SENSITIVE = [] include Aws::Structure end |