Class: Aws::CleanRoomsML::Types::GetConfiguredModelAlgorithmResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::GetConfiguredModelAlgorithmResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configured_model_algorithm_arn ⇒ String
The Amazon Resource Name (ARN) of the configured model algorithm.
-
#create_time ⇒ Time
The time at which the configured model algorithm was created.
-
#description ⇒ String
The description of the configured model algorithm.
-
#inference_container_config ⇒ Types::InferenceContainerConfig
Configuration information for the inference container.
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key.
-
#name ⇒ String
The name of the configured model algorithm.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the service role that was used to create the configured model algorithm.
-
#tags ⇒ Hash<String,String>
The optional metadata that you applied to the resource to help you categorize and organize them.
-
#training_container_config ⇒ Types::ContainerConfig
The configuration information of the training container for the configured model algorithm.
-
#update_time ⇒ Time
The most recent time at which the configured model algorithm was updated.
Instance Attribute Details
#configured_model_algorithm_arn ⇒ String
The Amazon Resource Name (ARN) of the configured model algorithm.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2970 class GetConfiguredModelAlgorithmResponse < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :training_container_config, :inference_container_config, :role_arn, :description, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the configured model algorithm was created.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2970 class GetConfiguredModelAlgorithmResponse < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :training_container_config, :inference_container_config, :role_arn, :description, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the configured model algorithm.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2970 class GetConfiguredModelAlgorithmResponse < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :training_container_config, :inference_container_config, :role_arn, :description, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#inference_container_config ⇒ Types::InferenceContainerConfig
Configuration information for the inference container.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2970 class GetConfiguredModelAlgorithmResponse < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :training_container_config, :inference_container_config, :role_arn, :description, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key. This key is used to encrypt and decrypt customer-owned data in the configured ML model and associated data.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2970 class GetConfiguredModelAlgorithmResponse < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :training_container_config, :inference_container_config, :role_arn, :description, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the configured model algorithm.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2970 class GetConfiguredModelAlgorithmResponse < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :training_container_config, :inference_container_config, :role_arn, :description, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the service role that was used to create the configured model algorithm.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2970 class GetConfiguredModelAlgorithmResponse < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :training_container_config, :inference_container_config, :role_arn, :description, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The optional metadata that you applied to the resource to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define.
The following basic restrictions apply to tags:
-
Maximum number of tags per resource - 50.
-
For each resource, each tag key must be unique, and each tag key can have only one value.
-
Maximum key length - 128 Unicode characters in UTF-8.
-
Maximum value length - 256 Unicode characters in UTF-8.
-
If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
-
Tag keys and values are case sensitive.
-
Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for keys as it is reserved for AWS use. You cannot edit or delete tag keys with this prefix. Values can have this prefix. If a tag value has aws as its prefix but the key does not, then Clean Rooms ML considers it to be a user tag and will count against the limit of 50 tags. Tags with only the key prefix of aws do not count against your tags per resource limit.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2970 class GetConfiguredModelAlgorithmResponse < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :training_container_config, :inference_container_config, :role_arn, :description, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#training_container_config ⇒ Types::ContainerConfig
The configuration information of the training container for the configured model algorithm.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2970 class GetConfiguredModelAlgorithmResponse < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :training_container_config, :inference_container_config, :role_arn, :description, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the configured model algorithm was updated.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2970 class GetConfiguredModelAlgorithmResponse < Struct.new( :create_time, :update_time, :configured_model_algorithm_arn, :name, :training_container_config, :inference_container_config, :role_arn, :description, :tags, :kms_key_arn) SENSITIVE = [] include Aws::Structure end |