Class: Aws::CleanRoomsML::Types::GetTrainedModelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#membership_identifierString

The membership ID of the member that created the trained model that you are interested in.



3350
3351
3352
3353
3354
3355
3356
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 3350

class GetTrainedModelRequest < Struct.new(
  :trained_model_arn,
  :membership_identifier,
  :version_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#trained_model_arnString

The Amazon Resource Name (ARN) of the trained model that you are interested in.



3350
3351
3352
3353
3354
3355
3356
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 3350

class GetTrainedModelRequest < Struct.new(
  :trained_model_arn,
  :membership_identifier,
  :version_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#version_identifierString

The version identifier of the trained model to retrieve. If not specified, the operation returns information about the latest version of the trained model.



3350
3351
3352
3353
3354
3355
3356
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 3350

class GetTrainedModelRequest < Struct.new(
  :trained_model_arn,
  :membership_identifier,
  :version_identifier)
  SENSITIVE = []
  include Aws::Structure
end