Class: Aws::CleanRoomsML::Types::IncrementalTrainingDataChannelOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::IncrementalTrainingDataChannelOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Contains information about an incremental training data channel that was used to create a trained model. This structure provides details about the base model and channel configuration used during incremental training.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_name ⇒ String
The name of the incremental training data channel that was used.
-
#model_name ⇒ String
The name of the base trained model that was used for incremental training.
-
#version_identifier ⇒ String
The version identifier of the trained model that was used for incremental training.
Instance Attribute Details
#channel_name ⇒ String
The name of the incremental training data channel that was used.
3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 3733 class IncrementalTrainingDataChannelOutput < Struct.new( :channel_name, :version_identifier, :model_name) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the base trained model that was used for incremental training.
3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 3733 class IncrementalTrainingDataChannelOutput < Struct.new( :channel_name, :version_identifier, :model_name) SENSITIVE = [] include Aws::Structure end |
#version_identifier ⇒ String
The version identifier of the trained model that was used for incremental training.
3733 3734 3735 3736 3737 3738 3739 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 3733 class IncrementalTrainingDataChannelOutput < Struct.new( :channel_name, :version_identifier, :model_name) SENSITIVE = [] include Aws::Structure end |