Class: Aws::CleanRoomsML::Types::ListConfiguredAudienceModelsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum size of the results that is returned per call.

Returns:

  • (Integer)


4203
4204
4205
4206
4207
4208
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4203

class ListConfiguredAudienceModelsRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The token value retrieved from a previous call to access the next page of results.

Returns:

  • (String)


4203
4204
4205
4206
4207
4208
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4203

class ListConfiguredAudienceModelsRequest < Struct.new(
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end