Class: Aws::CleanRoomsML::Types::ListConfiguredModelAlgorithmAssociationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::ListConfiguredModelAlgorithmAssociationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum size of the results that is returned per call.
-
#membership_identifier ⇒ String
The membership ID of the member that created the configured model algorithm associations you are interested in.
-
#next_token ⇒ String
The token value retrieved from a previous call to access the next page of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum size of the results that is returned per call.
4243 4244 4245 4246 4247 4248 4249 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4243 class ListConfiguredModelAlgorithmAssociationsRequest < Struct.new( :next_token, :max_results, :membership_identifier) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The membership ID of the member that created the configured model algorithm associations you are interested in.
4243 4244 4245 4246 4247 4248 4249 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4243 class ListConfiguredModelAlgorithmAssociationsRequest < Struct.new( :next_token, :max_results, :membership_identifier) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token value retrieved from a previous call to access the next page of results.
4243 4244 4245 4246 4247 4248 4249 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4243 class ListConfiguredModelAlgorithmAssociationsRequest < Struct.new( :next_token, :max_results, :membership_identifier) SENSITIVE = [] include Aws::Structure end |