Class: Aws::CleanRoomsML::Types::ListTrainedModelInferenceJobsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::ListTrainedModelInferenceJobsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum size of the results that is returned per call.
-
#membership_identifier ⇒ String
The membership.
-
#next_token ⇒ String
The token value retrieved from a previous call to access the next page of results.
-
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of a trained model that was used to create the trained model inference jobs that you are interested in.
-
#trained_model_version_identifier ⇒ String
The version identifier of the trained model to filter inference jobs by.
Instance Attribute Details
#max_results ⇒ Integer
The maximum size of the results that is returned per call.
4452 4453 4454 4455 4456 4457 4458 4459 4460 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4452 class ListTrainedModelInferenceJobsRequest < Struct.new( :next_token, :max_results, :membership_identifier, :trained_model_arn, :trained_model_version_identifier) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The membership
4452 4453 4454 4455 4456 4457 4458 4459 4460 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4452 class ListTrainedModelInferenceJobsRequest < Struct.new( :next_token, :max_results, :membership_identifier, :trained_model_arn, :trained_model_version_identifier) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token value retrieved from a previous call to access the next page of results.
4452 4453 4454 4455 4456 4457 4458 4459 4460 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4452 class ListTrainedModelInferenceJobsRequest < Struct.new( :next_token, :max_results, :membership_identifier, :trained_model_arn, :trained_model_version_identifier) SENSITIVE = [] include Aws::Structure end |
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of a trained model that was used to create the trained model inference jobs that you are interested in.
4452 4453 4454 4455 4456 4457 4458 4459 4460 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4452 class ListTrainedModelInferenceJobsRequest < Struct.new( :next_token, :max_results, :membership_identifier, :trained_model_arn, :trained_model_version_identifier) SENSITIVE = [] include Aws::Structure end |
#trained_model_version_identifier ⇒ String
The version identifier of the trained model to filter inference jobs by. When specified, only inference jobs that used this specific version of the trained model are returned.
4452 4453 4454 4455 4456 4457 4458 4459 4460 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4452 class ListTrainedModelInferenceJobsRequest < Struct.new( :next_token, :max_results, :membership_identifier, :trained_model_arn, :trained_model_version_identifier) SENSITIVE = [] include Aws::Structure end |