Class: Aws::CleanRoomsML::Types::ListTrainedModelVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of trained model versions to return in a single page. The default value is 10, and the maximum value is 100.

Returns:

  • (Integer)


4450
4451
4452
4453
4454
4455
4456
4457
4458
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4450

class ListTrainedModelVersionsRequest < Struct.new(
  :next_token,
  :max_results,
  :membership_identifier,
  :trained_model_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The membership identifier for the collaboration that contains the trained model.

Returns:

  • (String)


4450
4451
4452
4453
4454
4455
4456
4457
4458
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4450

class ListTrainedModelVersionsRequest < Struct.new(
  :next_token,
  :max_results,
  :membership_identifier,
  :trained_model_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token from a previous ListTrainedModelVersions request. Use this token to retrieve the next page of results.

Returns:

  • (String)


4450
4451
4452
4453
4454
4455
4456
4457
4458
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4450

class ListTrainedModelVersionsRequest < Struct.new(
  :next_token,
  :max_results,
  :membership_identifier,
  :trained_model_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Filter the results to only include trained model versions with the specified status. Valid values include CREATE_PENDING, CREATE_IN_PROGRESS, ACTIVE, CREATE_FAILED, and others.

Returns:

  • (String)


4450
4451
4452
4453
4454
4455
4456
4457
4458
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4450

class ListTrainedModelVersionsRequest < Struct.new(
  :next_token,
  :max_results,
  :membership_identifier,
  :trained_model_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#trained_model_arnString

The Amazon Resource Name (ARN) of the trained model for which to list versions.

Returns:

  • (String)


4450
4451
4452
4453
4454
4455
4456
4457
4458
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4450

class ListTrainedModelVersionsRequest < Struct.new(
  :next_token,
  :max_results,
  :membership_identifier,
  :trained_model_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end