Class: Aws::CleanRoomsML::Types::ListTrainedModelVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::ListTrainedModelVersionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The pagination token to use in a subsequent
ListTrainedModelVersionsrequest to retrieve the next page of results. -
#trained_models ⇒ Array<Types::TrainedModelSummary>
A list of trained model versions that match the specified criteria.
Instance Attribute Details
#next_token ⇒ String
The pagination token to use in a subsequent ListTrainedModelVersions request to retrieve the next page of results. This value is null when there are no more results to return.
4476 4477 4478 4479 4480 4481 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4476 class ListTrainedModelVersionsResponse < Struct.new( :next_token, :trained_models) SENSITIVE = [] include Aws::Structure end |
#trained_models ⇒ Array<Types::TrainedModelSummary>
A list of trained model versions that match the specified criteria. Each entry contains summary information about a trained model version, including its version identifier, status, and creation details.
4476 4477 4478 4479 4480 4481 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4476 class ListTrainedModelVersionsResponse < Struct.new( :next_token, :trained_models) SENSITIVE = [] include Aws::Structure end |