Class: Aws::CleanRoomsML::Types::ListTrainedModelsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::ListTrainedModelsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum size of the results that is returned per call.
-
#membership_identifier ⇒ String
The membership ID of the member that created the trained models you are interested in.
-
#next_token ⇒ String
The token value retrieved from a previous call to access the next page of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum size of the results that is returned per call.
4556 4557 4558 4559 4560 4561 4562 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4556 class ListTrainedModelsRequest < Struct.new( :next_token, :max_results, :membership_identifier) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The membership ID of the member that created the trained models you are interested in.
4556 4557 4558 4559 4560 4561 4562 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4556 class ListTrainedModelsRequest < Struct.new( :next_token, :max_results, :membership_identifier) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token value retrieved from a previous call to access the next page of results.
4556 4557 4558 4559 4560 4561 4562 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4556 class ListTrainedModelsRequest < Struct.new( :next_token, :max_results, :membership_identifier) SENSITIVE = [] include Aws::Structure end |