Class: Aws::CleanRoomsML::Types::LogRedactionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

The configuration for log redaction.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#custom_entity_configTypes::CustomEntityConfig

Specifies the configuration for custom entities in the context of log redaction.



4633
4634
4635
4636
4637
4638
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4633

class LogRedactionConfiguration < Struct.new(
  :entities_to_redact,
  :custom_entity_config)
  SENSITIVE = []
  include Aws::Structure
end

#entities_to_redactArray<String>

Specifies the entities to be redacted from logs. Entities to redact are “ALL_PERSONALLY_IDENTIFIABLE_INFORMATION”, “NUMBERS”,“CUSTOM”. If CUSTOM is supplied or configured, custom patterns (customDataIdentifiers) should be provided, and the patterns will be redacted in logs or error messages.

Returns:

  • (Array<String>)


4633
4634
4635
4636
4637
4638
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4633

class LogRedactionConfiguration < Struct.new(
  :entities_to_redact,
  :custom_entity_config)
  SENSITIVE = []
  include Aws::Structure
end