Class: Aws::CleanRoomsML::Types::PrivacyBudgets
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::PrivacyBudgets
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Note:
PrivacyBudgets is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PrivacyBudgets corresponding to the set member.
The privacy budget information that controls access to Clean Rooms ML input channels.
Direct Known Subclasses
Defined Under Namespace
Classes: AccessBudgets, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_budgets ⇒ Array<Types::AccessBudget>
A list of access budgets that apply to resources associated with this Clean Rooms ML input channel.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#access_budgets ⇒ Array<Types::AccessBudget>
A list of access budgets that apply to resources associated with this Clean Rooms ML input channel.
4937 4938 4939 4940 4941 4942 4943 4944 4945 4946 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4937 class PrivacyBudgets < Struct.new( :access_budgets, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AccessBudgets < PrivacyBudgets; end class Unknown < PrivacyBudgets; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4937 4938 4939 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4937 def unknown @unknown end |