Class: Aws::CleanRoomsML::Types::ProtectedQueryInputParameters
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::ProtectedQueryInputParameters
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Provides information necessary to perform the protected query.
Constant Summary collapse
- SENSITIVE =
[:sql_parameters]
Instance Attribute Summary collapse
-
#compute_configuration ⇒ Types::ComputeConfiguration
Provides configuration information for the workers that will perform the protected query.
-
#result_format ⇒ String
The format in which the query results should be returned.
-
#sql_parameters ⇒ Types::ProtectedQuerySQLParameters
The parameters for the SQL type Protected Query.
Instance Attribute Details
#compute_configuration ⇒ Types::ComputeConfiguration
Provides configuration information for the workers that will perform the protected query.
5007 5008 5009 5010 5011 5012 5013 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5007 class ProtectedQueryInputParameters < Struct.new( :sql_parameters, :compute_configuration, :result_format) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#result_format ⇒ String
The format in which the query results should be returned. If not specified, defaults to ‘CSV`.
5007 5008 5009 5010 5011 5012 5013 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5007 class ProtectedQueryInputParameters < Struct.new( :sql_parameters, :compute_configuration, :result_format) SENSITIVE = [:sql_parameters] include Aws::Structure end |
#sql_parameters ⇒ Types::ProtectedQuerySQLParameters
The parameters for the SQL type Protected Query.
5007 5008 5009 5010 5011 5012 5013 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5007 class ProtectedQueryInputParameters < Struct.new( :sql_parameters, :compute_configuration, :result_format) SENSITIVE = [:sql_parameters] include Aws::Structure end |