Class: Aws::CleanRoomsML::Types::ResourceConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Information about the EC2 resources that are used to train the model.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_countInteger

The number of resources that are used to train the model.

Returns:

  • (Integer)


5064
5065
5066
5067
5068
5069
5070
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5064

class ResourceConfig < Struct.new(
  :instance_count,
  :instance_type,
  :volume_size_in_gb)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type that is used to train the model.

Returns:

  • (String)


5064
5065
5066
5067
5068
5069
5070
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5064

class ResourceConfig < Struct.new(
  :instance_count,
  :instance_type,
  :volume_size_in_gb)
  SENSITIVE = []
  include Aws::Structure
end

#volume_size_in_gbInteger

The volume size of the instance that is used to train the model. Please see [EC2 volume limit] for volume size limitations on different instance types.

[1]: docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-store-volumes.html

Returns:

  • (Integer)


5064
5065
5066
5067
5068
5069
5070
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5064

class ResourceConfig < Struct.new(
  :instance_count,
  :instance_type,
  :volume_size_in_gb)
  SENSITIVE = []
  include Aws::Structure
end