Class: Aws::CleanRoomsML::Types::StartTrainedModelExportJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the trained model export job.



5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5268

class StartTrainedModelExportJobRequest < Struct.new(
  :name,
  :trained_model_arn,
  :trained_model_version_identifier,
  :membership_identifier,
  :output_configuration,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The membership ID of the member that is receiving the exported trained model artifacts.



5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5268

class StartTrainedModelExportJobRequest < Struct.new(
  :name,
  :trained_model_arn,
  :trained_model_version_identifier,
  :membership_identifier,
  :output_configuration,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the trained model export job.



5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5268

class StartTrainedModelExportJobRequest < Struct.new(
  :name,
  :trained_model_arn,
  :trained_model_version_identifier,
  :membership_identifier,
  :output_configuration,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#output_configurationTypes::TrainedModelExportOutputConfiguration

The output configuration information for the trained model export job.



5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5268

class StartTrainedModelExportJobRequest < Struct.new(
  :name,
  :trained_model_arn,
  :trained_model_version_identifier,
  :membership_identifier,
  :output_configuration,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#trained_model_arnString

The Amazon Resource Name (ARN) of the trained model that you want to export.



5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5268

class StartTrainedModelExportJobRequest < Struct.new(
  :name,
  :trained_model_arn,
  :trained_model_version_identifier,
  :membership_identifier,
  :output_configuration,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#trained_model_version_identifierString

The version identifier of the trained model to export. This specifies which version of the trained model should be exported to the specified destination.



5268
5269
5270
5271
5272
5273
5274
5275
5276
5277
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5268

class StartTrainedModelExportJobRequest < Struct.new(
  :name,
  :trained_model_arn,
  :trained_model_version_identifier,
  :membership_identifier,
  :output_configuration,
  :description)
  SENSITIVE = []
  include Aws::Structure
end