Class: Aws::CleanRoomsML::Types::TrainedModelSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Summary information about the trained model.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#collaboration_identifierString

The collaboration ID of the collaboration that contains the trained model.

Returns:

  • (String)


5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#configured_model_algorithm_association_arnString

The Amazon Resource Name (ARN) of the configured model algorithm association that was used to create this trained model.

Returns:

  • (String)


5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#create_timeTime

The time at which the trained model was created.

Returns:

  • (Time)


5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the trained model.

Returns:

  • (String)


5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#incremental_training_data_channelsArray<Types::IncrementalTrainingDataChannelOutput>

Information about the incremental training data channels used to create this version of the trained model.



5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#membership_identifierString

The membership ID of the member that created the trained model.

Returns:

  • (String)


5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#ml_model_training_payer_account_idString

The account ID of the member that is responsible for paying for model training costs.

Returns:

  • (String)


5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the trained model.

Returns:

  • (String)


5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the trained model.

Returns:

  • (String)


5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#trained_model_arnString

The Amazon Resource Name (ARN) of the trained model.

Returns:

  • (String)


5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#update_timeTime

The most recent time at which the trained model was updated.

Returns:

  • (Time)


5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#version_identifierString

The version identifier of this trained model version.

Returns:

  • (String)


5963
5964
5965
5966
5967
5968
5969
5970
5971
5972
5973
5974
5975
5976
5977
5978
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5963

class TrainedModelSummary < Struct.new(
  :create_time,
  :update_time,
  :trained_model_arn,
  :version_identifier,
  :incremental_training_data_channels,
  :name,
  :description,
  :membership_identifier,
  :collaboration_identifier,
  :status,
  :configured_model_algorithm_association_arn,
  :ml_model_training_payer_account_id)
  SENSITIVE = []
  include Aws::Structure
end