Class: Aws::CleanRoomsML::Types::TrainingDatasetSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::TrainingDatasetSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Provides information about the training dataset.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_time ⇒ Time
The time at which the training dataset was created.
-
#description ⇒ String
The description of the training dataset.
-
#name ⇒ String
The name of the training dataset.
-
#status ⇒ String
The status of the training dataset.
-
#training_dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the training dataset.
-
#update_time ⇒ Time
The most recent time at which the training dataset was updated.
Instance Attribute Details
#create_time ⇒ Time
The time at which the training dataset was created.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6034 class TrainingDatasetSummary < Struct.new( :create_time, :update_time, :training_dataset_arn, :name, :status, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the training dataset.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6034 class TrainingDatasetSummary < Struct.new( :create_time, :update_time, :training_dataset_arn, :name, :status, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the training dataset.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6034 class TrainingDatasetSummary < Struct.new( :create_time, :update_time, :training_dataset_arn, :name, :status, :description) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the training dataset.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6034 class TrainingDatasetSummary < Struct.new( :create_time, :update_time, :training_dataset_arn, :name, :status, :description) SENSITIVE = [] include Aws::Structure end |
#training_dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the training dataset.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6034 class TrainingDatasetSummary < Struct.new( :create_time, :update_time, :training_dataset_arn, :name, :status, :description) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the training dataset was updated.
6034 6035 6036 6037 6038 6039 6040 6041 6042 6043 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6034 class TrainingDatasetSummary < Struct.new( :create_time, :update_time, :training_dataset_arn, :name, :status, :description) SENSITIVE = [] include Aws::Structure end |