Class: Aws::CleanRoomsML::Types::UpdateConfiguredAudienceModelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::UpdateConfiguredAudienceModelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the new audience model that you want to use.
-
#audience_size_config ⇒ Types::AudienceSizeConfig
The new audience size configuration.
-
#configured_audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the configured audience model that you want to update.
-
#description ⇒ String
The new description of the configured audience model.
-
#min_matching_seed_size ⇒ Integer
The minimum number of users from the seed audience that must match with users in the training data of the audience model.
-
#output_config ⇒ Types::ConfiguredAudienceModelOutputConfig
The new output configuration.
-
#shared_audience_metrics ⇒ Array<String>
The new value for whether to share audience metrics.
Instance Attribute Details
#audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the new audience model that you want to use.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6100 class UpdateConfiguredAudienceModelRequest < Struct.new( :configured_audience_model_arn, :output_config, :audience_model_arn, :shared_audience_metrics, :min_matching_seed_size, :audience_size_config, :description) SENSITIVE = [] include Aws::Structure end |
#audience_size_config ⇒ Types::AudienceSizeConfig
The new audience size configuration.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6100 class UpdateConfiguredAudienceModelRequest < Struct.new( :configured_audience_model_arn, :output_config, :audience_model_arn, :shared_audience_metrics, :min_matching_seed_size, :audience_size_config, :description) SENSITIVE = [] include Aws::Structure end |
#configured_audience_model_arn ⇒ String
The Amazon Resource Name (ARN) of the configured audience model that you want to update.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6100 class UpdateConfiguredAudienceModelRequest < Struct.new( :configured_audience_model_arn, :output_config, :audience_model_arn, :shared_audience_metrics, :min_matching_seed_size, :audience_size_config, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The new description of the configured audience model.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6100 class UpdateConfiguredAudienceModelRequest < Struct.new( :configured_audience_model_arn, :output_config, :audience_model_arn, :shared_audience_metrics, :min_matching_seed_size, :audience_size_config, :description) SENSITIVE = [] include Aws::Structure end |
#min_matching_seed_size ⇒ Integer
The minimum number of users from the seed audience that must match with users in the training data of the audience model.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6100 class UpdateConfiguredAudienceModelRequest < Struct.new( :configured_audience_model_arn, :output_config, :audience_model_arn, :shared_audience_metrics, :min_matching_seed_size, :audience_size_config, :description) SENSITIVE = [] include Aws::Structure end |
#output_config ⇒ Types::ConfiguredAudienceModelOutputConfig
The new output configuration.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6100 class UpdateConfiguredAudienceModelRequest < Struct.new( :configured_audience_model_arn, :output_config, :audience_model_arn, :shared_audience_metrics, :min_matching_seed_size, :audience_size_config, :description) SENSITIVE = [] include Aws::Structure end |
#shared_audience_metrics ⇒ Array<String>
The new value for whether to share audience metrics.
6100 6101 6102 6103 6104 6105 6106 6107 6108 6109 6110 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6100 class UpdateConfiguredAudienceModelRequest < Struct.new( :configured_audience_model_arn, :output_config, :audience_model_arn, :shared_audience_metrics, :min_matching_seed_size, :audience_size_config, :description) SENSITIVE = [] include Aws::Structure end |