Class: Aws::CleanRoomsML::Types::WorkerComputeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Configuration information about the compute workers that perform the transform job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#numberInteger

The number of compute workers that are used.

Returns:

  • (Integer)


6055
6056
6057
6058
6059
6060
6061
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6055

class WorkerComputeConfiguration < Struct.new(
  :type,
  :number,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#propertiesTypes::WorkerComputeConfigurationProperties

The configuration properties for the worker compute environment. These properties allow you to customize the compute settings for your Clean Rooms workloads.



6055
6056
6057
6058
6059
6060
6061
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6055

class WorkerComputeConfiguration < Struct.new(
  :type,
  :number,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The instance type of the compute workers that are used.

Returns:

  • (String)


6055
6056
6057
6058
6059
6060
6061
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6055

class WorkerComputeConfiguration < Struct.new(
  :type,
  :number,
  :properties)
  SENSITIVE = []
  include Aws::Structure
end