Class: Aws::CleanRoomsML::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CleanRoomsML::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cleanroomsml/client.rb
Overview
An API client for CleanRoomsML. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::CleanRoomsML::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_trained_model(params = {}) ⇒ Struct
Submits a request to cancel the trained model job.
-
#cancel_trained_model_inference_job(params = {}) ⇒ Struct
Submits a request to cancel a trained model inference job.
-
#create_audience_model(params = {}) ⇒ Types::CreateAudienceModelResponse
Defines the information necessary to create an audience model.
-
#create_configured_audience_model(params = {}) ⇒ Types::CreateConfiguredAudienceModelResponse
Defines the information necessary to create a configured audience model.
-
#create_configured_model_algorithm(params = {}) ⇒ Types::CreateConfiguredModelAlgorithmResponse
Creates a configured model algorithm using a container image stored in an ECR repository.
-
#create_configured_model_algorithm_association(params = {}) ⇒ Types::CreateConfiguredModelAlgorithmAssociationResponse
Associates a configured model algorithm to a collaboration for use by any member of the collaboration.
-
#create_ml_input_channel(params = {}) ⇒ Types::CreateMLInputChannelResponse
Provides the information to create an ML input channel.
-
#create_trained_model(params = {}) ⇒ Types::CreateTrainedModelResponse
Creates a trained model from an associated configured model algorithm using data from any member of the collaboration.
-
#create_training_dataset(params = {}) ⇒ Types::CreateTrainingDatasetResponse
Defines the information necessary to create a training dataset.
-
#delete_audience_generation_job(params = {}) ⇒ Struct
Deletes the specified audience generation job, and removes all data associated with the job.
-
#delete_audience_model(params = {}) ⇒ Struct
Specifies an audience model that you want to delete.
-
#delete_configured_audience_model(params = {}) ⇒ Struct
Deletes the specified configured audience model.
-
#delete_configured_audience_model_policy(params = {}) ⇒ Struct
Deletes the specified configured audience model policy.
-
#delete_configured_model_algorithm(params = {}) ⇒ Struct
Deletes a configured model algorithm.
-
#delete_configured_model_algorithm_association(params = {}) ⇒ Struct
Deletes a configured model algorithm association.
-
#delete_ml_configuration(params = {}) ⇒ Struct
Deletes a ML modeling configuration.
-
#delete_ml_input_channel_data(params = {}) ⇒ Struct
Provides the information necessary to delete an ML input channel.
-
#delete_trained_model_output(params = {}) ⇒ Struct
Deletes the model artifacts stored by the service.
-
#delete_training_dataset(params = {}) ⇒ Struct
Specifies a training dataset that you want to delete.
-
#get_audience_generation_job(params = {}) ⇒ Types::GetAudienceGenerationJobResponse
Returns information about an audience generation job.
-
#get_audience_model(params = {}) ⇒ Types::GetAudienceModelResponse
Returns information about an audience model.
-
#get_collaboration_configured_model_algorithm_association(params = {}) ⇒ Types::GetCollaborationConfiguredModelAlgorithmAssociationResponse
Returns information about the configured model algorithm association in a collaboration.
-
#get_collaboration_ml_input_channel(params = {}) ⇒ Types::GetCollaborationMLInputChannelResponse
Returns information about a specific ML input channel in a collaboration.
-
#get_collaboration_trained_model(params = {}) ⇒ Types::GetCollaborationTrainedModelResponse
Returns information about a trained model in a collaboration.
-
#get_configured_audience_model(params = {}) ⇒ Types::GetConfiguredAudienceModelResponse
Returns information about a specified configured audience model.
-
#get_configured_audience_model_policy(params = {}) ⇒ Types::GetConfiguredAudienceModelPolicyResponse
Returns information about a configured audience model policy.
-
#get_configured_model_algorithm(params = {}) ⇒ Types::GetConfiguredModelAlgorithmResponse
Returns information about a configured model algorithm.
-
#get_configured_model_algorithm_association(params = {}) ⇒ Types::GetConfiguredModelAlgorithmAssociationResponse
Returns information about a configured model algorithm association.
-
#get_ml_configuration(params = {}) ⇒ Types::GetMLConfigurationResponse
Returns information about a specific ML configuration.
-
#get_ml_input_channel(params = {}) ⇒ Types::GetMLInputChannelResponse
Returns information about an ML input channel.
-
#get_trained_model(params = {}) ⇒ Types::GetTrainedModelResponse
Returns information about a trained model.
-
#get_trained_model_inference_job(params = {}) ⇒ Types::GetTrainedModelInferenceJobResponse
Returns information about a trained model inference job.
-
#get_training_dataset(params = {}) ⇒ Types::GetTrainingDatasetResponse
Returns information about a training dataset.
-
#list_audience_export_jobs(params = {}) ⇒ Types::ListAudienceExportJobsResponse
Returns a list of the audience export jobs.
-
#list_audience_generation_jobs(params = {}) ⇒ Types::ListAudienceGenerationJobsResponse
Returns a list of audience generation jobs.
-
#list_audience_models(params = {}) ⇒ Types::ListAudienceModelsResponse
Returns a list of audience models.
-
#list_collaboration_configured_model_algorithm_associations(params = {}) ⇒ Types::ListCollaborationConfiguredModelAlgorithmAssociationsResponse
Returns a list of the configured model algorithm associations in a collaboration.
-
#list_collaboration_ml_input_channels(params = {}) ⇒ Types::ListCollaborationMLInputChannelsResponse
Returns a list of the ML input channels in a collaboration.
-
#list_collaboration_trained_model_export_jobs(params = {}) ⇒ Types::ListCollaborationTrainedModelExportJobsResponse
Returns a list of the export jobs for a trained model in a collaboration.
-
#list_collaboration_trained_model_inference_jobs(params = {}) ⇒ Types::ListCollaborationTrainedModelInferenceJobsResponse
Returns a list of trained model inference jobs in a specified collaboration.
-
#list_collaboration_trained_models(params = {}) ⇒ Types::ListCollaborationTrainedModelsResponse
Returns a list of the trained models in a collaboration.
-
#list_configured_audience_models(params = {}) ⇒ Types::ListConfiguredAudienceModelsResponse
Returns a list of the configured audience models.
-
#list_configured_model_algorithm_associations(params = {}) ⇒ Types::ListConfiguredModelAlgorithmAssociationsResponse
Returns a list of configured model algorithm associations.
-
#list_configured_model_algorithms(params = {}) ⇒ Types::ListConfiguredModelAlgorithmsResponse
Returns a list of configured model algorithms.
-
#list_ml_input_channels(params = {}) ⇒ Types::ListMLInputChannelsResponse
Returns a list of ML input channels.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a provided resource.
-
#list_trained_model_inference_jobs(params = {}) ⇒ Types::ListTrainedModelInferenceJobsResponse
Returns a list of trained model inference jobs that match the request parameters.
-
#list_trained_model_versions(params = {}) ⇒ Types::ListTrainedModelVersionsResponse
Returns a list of trained model versions for a specified trained model.
-
#list_trained_models(params = {}) ⇒ Types::ListTrainedModelsResponse
Returns a list of trained models.
-
#list_training_datasets(params = {}) ⇒ Types::ListTrainingDatasetsResponse
Returns a list of training datasets.
-
#put_configured_audience_model_policy(params = {}) ⇒ Types::PutConfiguredAudienceModelPolicyResponse
Create or update the resource policy for a configured audience model.
-
#put_ml_configuration(params = {}) ⇒ Struct
Assigns information about an ML configuration.
-
#start_audience_export_job(params = {}) ⇒ Struct
Export an audience of a specified size after you have generated an audience.
-
#start_audience_generation_job(params = {}) ⇒ Types::StartAudienceGenerationJobResponse
Information necessary to start the audience generation job.
-
#start_trained_model_export_job(params = {}) ⇒ Struct
Provides the information necessary to start a trained model export job.
-
#start_trained_model_inference_job(params = {}) ⇒ Types::StartTrainedModelInferenceJobResponse
Defines the information necessary to begin a trained model inference job.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a specified resource.
-
#update_configured_audience_model(params = {}) ⇒ Types::UpdateConfiguredAudienceModelResponse
Provides the information necessary to update a configured audience model.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4162 4163 4164 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 4162 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4165 4166 4167 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 4165 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 4148 4149 4150 4151 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 4135 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CleanRoomsML') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cleanroomsml' context[:gem_version] = '1.47.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_trained_model(params = {}) ⇒ Struct
Submits a request to cancel the trained model job.
508 509 510 511 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 508 def cancel_trained_model(params = {}, = {}) req = build_request(:cancel_trained_model, params) req.send_request() end |
#cancel_trained_model_inference_job(params = {}) ⇒ Struct
Submits a request to cancel a trained model inference job.
536 537 538 539 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 536 def cancel_trained_model_inference_job(params = {}, = {}) req = build_request(:cancel_trained_model_inference_job, params) req.send_request() end |
#create_audience_model(params = {}) ⇒ Types::CreateAudienceModelResponse
Defines the information necessary to create an audience model. An audience model is a machine learning model that Clean Rooms ML trains to measure similarity between users. Clean Rooms ML manages training and storing the audience model. The audience model can be used in multiple calls to the StartAudienceGenerationJob API.
626 627 628 629 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 626 def create_audience_model(params = {}, = {}) req = build_request(:create_audience_model, params) req.send_request() end |
#create_configured_audience_model(params = {}) ⇒ Types::CreateConfiguredAudienceModelResponse
Defines the information necessary to create a configured audience model.
752 753 754 755 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 752 def create_configured_audience_model(params = {}, = {}) req = build_request(:create_configured_audience_model, params) req.send_request() end |
#create_configured_model_algorithm(params = {}) ⇒ Types::CreateConfiguredModelAlgorithmResponse
Creates a configured model algorithm using a container image stored in an ECR repository.
853 854 855 856 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 853 def create_configured_model_algorithm(params = {}, = {}) req = build_request(:create_configured_model_algorithm, params) req.send_request() end |
#create_configured_model_algorithm_association(params = {}) ⇒ Types::CreateConfiguredModelAlgorithmAssociationResponse
Associates a configured model algorithm to a collaboration for use by any member of the collaboration.
988 989 990 991 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 988 def create_configured_model_algorithm_association(params = {}, = {}) req = build_request(:create_configured_model_algorithm_association, params) req.send_request() end |
#create_ml_input_channel(params = {}) ⇒ Types::CreateMLInputChannelResponse
Provides the information to create an ML input channel. An ML input channel is the result of a query that can be used for ML modeling.
1111 1112 1113 1114 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1111 def create_ml_input_channel(params = {}, = {}) req = build_request(:create_ml_input_channel, params) req.send_request() end |
#create_trained_model(params = {}) ⇒ Types::CreateTrainedModelResponse
Creates a trained model from an associated configured model algorithm using data from any member of the collaboration.
1277 1278 1279 1280 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1277 def create_trained_model(params = {}, = {}) req = build_request(:create_trained_model, params) req.send_request() end |
#create_training_dataset(params = {}) ⇒ Types::CreateTrainingDatasetResponse
Defines the information necessary to create a training dataset. In Clean Rooms ML, the ‘TrainingDataset` is metadata that points to a Glue table, which is read only during `AudienceModel` creation.
1380 1381 1382 1383 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1380 def create_training_dataset(params = {}, = {}) req = build_request(:create_training_dataset, params) req.send_request() end |
#delete_audience_generation_job(params = {}) ⇒ Struct
Deletes the specified audience generation job, and removes all data associated with the job.
1404 1405 1406 1407 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1404 def delete_audience_generation_job(params = {}, = {}) req = build_request(:delete_audience_generation_job, params) req.send_request() end |
#delete_audience_model(params = {}) ⇒ Struct
Specifies an audience model that you want to delete. You can’t delete an audience model if there are any configured audience models that depend on the audience model.
1429 1430 1431 1432 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1429 def delete_audience_model(params = {}, = {}) req = build_request(:delete_audience_model, params) req.send_request() end |
#delete_configured_audience_model(params = {}) ⇒ Struct
Deletes the specified configured audience model. You can’t delete a configured audience model if there are any lookalike models that use the configured audience model. If you delete a configured audience model, it will be removed from any collaborations that it is associated to.
1456 1457 1458 1459 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1456 def delete_configured_audience_model(params = {}, = {}) req = build_request(:delete_configured_audience_model, params) req.send_request() end |
#delete_configured_audience_model_policy(params = {}) ⇒ Struct
Deletes the specified configured audience model policy.
1479 1480 1481 1482 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1479 def delete_configured_audience_model_policy(params = {}, = {}) req = build_request(:delete_configured_audience_model_policy, params) req.send_request() end |
#delete_configured_model_algorithm(params = {}) ⇒ Struct
Deletes a configured model algorithm.
1502 1503 1504 1505 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1502 def delete_configured_model_algorithm(params = {}, = {}) req = build_request(:delete_configured_model_algorithm, params) req.send_request() end |
#delete_configured_model_algorithm_association(params = {}) ⇒ Struct
Deletes a configured model algorithm association.
1530 1531 1532 1533 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1530 def delete_configured_model_algorithm_association(params = {}, = {}) req = build_request(:delete_configured_model_algorithm_association, params) req.send_request() end |
#delete_ml_configuration(params = {}) ⇒ Struct
Deletes a ML modeling configuration.
1553 1554 1555 1556 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1553 def delete_ml_configuration(params = {}, = {}) req = build_request(:delete_ml_configuration, params) req.send_request() end |
#delete_ml_input_channel_data(params = {}) ⇒ Struct
Provides the information necessary to delete an ML input channel.
1581 1582 1583 1584 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1581 def delete_ml_input_channel_data(params = {}, = {}) req = build_request(:delete_ml_input_channel_data, params) req.send_request() end |
#delete_trained_model_output(params = {}) ⇒ Struct
Deletes the model artifacts stored by the service.
1615 1616 1617 1618 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1615 def delete_trained_model_output(params = {}, = {}) req = build_request(:delete_trained_model_output, params) req.send_request() end |
#delete_training_dataset(params = {}) ⇒ Struct
Specifies a training dataset that you want to delete. You can’t delete a training dataset if there are any audience models that depend on the training dataset. In Clean Rooms ML, the ‘TrainingDataset` is metadata that points to a Glue table, which is read only during `AudienceModel` creation. This action deletes the metadata.
1642 1643 1644 1645 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1642 def delete_training_dataset(params = {}, = {}) req = build_request(:delete_training_dataset, params) req.send_request() end |
#get_audience_generation_job(params = {}) ⇒ Types::GetAudienceGenerationJobResponse
Returns information about an audience generation job.
1714 1715 1716 1717 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1714 def get_audience_generation_job(params = {}, = {}) req = build_request(:get_audience_generation_job, params) req.send_request() end |
#get_audience_model(params = {}) ⇒ Types::GetAudienceModelResponse
Returns information about an audience model
1767 1768 1769 1770 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1767 def get_audience_model(params = {}, = {}) req = build_request(:get_audience_model, params) req.send_request() end |
#get_collaboration_configured_model_algorithm_association(params = {}) ⇒ Types::GetCollaborationConfiguredModelAlgorithmAssociationResponse
Returns information about the configured model algorithm association in a collaboration.
1847 1848 1849 1850 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1847 def get_collaboration_configured_model_algorithm_association(params = {}, = {}) req = build_request(:get_collaboration_configured_model_algorithm_association, params) req.send_request() end |
#get_collaboration_ml_input_channel(params = {}) ⇒ Types::GetCollaborationMLInputChannelResponse
Returns information about a specific ML input channel in a collaboration.
1932 1933 1934 1935 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 1932 def get_collaboration_ml_input_channel(params = {}, = {}) req = build_request(:get_collaboration_ml_input_channel, params) req.send_request() end |
#get_collaboration_trained_model(params = {}) ⇒ Types::GetCollaborationTrainedModelResponse
Returns information about a trained model in a collaboration.
2020 2021 2022 2023 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2020 def get_collaboration_trained_model(params = {}, = {}) req = build_request(:get_collaboration_trained_model, params) req.send_request() end |
#get_configured_audience_model(params = {}) ⇒ Types::GetConfiguredAudienceModelResponse
Returns information about a specified configured audience model.
2078 2079 2080 2081 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2078 def get_configured_audience_model(params = {}, = {}) req = build_request(:get_configured_audience_model, params) req.send_request() end |
#get_configured_audience_model_policy(params = {}) ⇒ Types::GetConfiguredAudienceModelPolicyResponse
Returns information about a configured audience model policy.
2111 2112 2113 2114 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2111 def get_configured_audience_model_policy(params = {}, = {}) req = build_request(:get_configured_audience_model_policy, params) req.send_request() end |
#get_configured_model_algorithm(params = {}) ⇒ Types::GetConfiguredModelAlgorithmResponse
Returns information about a configured model algorithm.
2166 2167 2168 2169 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2166 def get_configured_model_algorithm(params = {}, = {}) req = build_request(:get_configured_model_algorithm, params) req.send_request() end |
#get_configured_model_algorithm_association(params = {}) ⇒ Types::GetConfiguredModelAlgorithmAssociationResponse
Returns information about a configured model algorithm association.
2245 2246 2247 2248 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2245 def get_configured_model_algorithm_association(params = {}, = {}) req = build_request(:get_configured_model_algorithm_association, params) req.send_request() end |
#get_ml_configuration(params = {}) ⇒ Types::GetMLConfigurationResponse
Returns information about a specific ML configuration.
2281 2282 2283 2284 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2281 def get_ml_configuration(params = {}, = {}) req = build_request(:get_ml_configuration, params) req.send_request() end |
#get_ml_input_channel(params = {}) ⇒ Types::GetMLInputChannelResponse
Returns information about an ML input channel.
2385 2386 2387 2388 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2385 def get_ml_input_channel(params = {}, = {}) req = build_request(:get_ml_input_channel, params) req.send_request() end |
#get_trained_model(params = {}) ⇒ Types::GetTrainedModelResponse
Returns information about a trained model.
2487 2488 2489 2490 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2487 def get_trained_model(params = {}, = {}) req = build_request(:get_trained_model, params) req.send_request() end |
#get_trained_model_inference_job(params = {}) ⇒ Types::GetTrainedModelInferenceJobResponse
Returns information about a trained model inference job.
2573 2574 2575 2576 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2573 def get_trained_model_inference_job(params = {}, = {}) req = build_request(:get_trained_model_inference_job, params) req.send_request() end |
#get_training_dataset(params = {}) ⇒ Types::GetTrainingDatasetResponse
Returns information about a training dataset.
2627 2628 2629 2630 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2627 def get_training_dataset(params = {}, = {}) req = build_request(:get_training_dataset, params) req.send_request() end |
#list_audience_export_jobs(params = {}) ⇒ Types::ListAudienceExportJobsResponse
Returns a list of the audience export jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2680 2681 2682 2683 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2680 def list_audience_export_jobs(params = {}, = {}) req = build_request(:list_audience_export_jobs, params) req.send_request() end |
#list_audience_generation_jobs(params = {}) ⇒ Types::ListAudienceGenerationJobsResponse
Returns a list of audience generation jobs.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2736 2737 2738 2739 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2736 def list_audience_generation_jobs(params = {}, = {}) req = build_request(:list_audience_generation_jobs, params) req.send_request() end |
#list_audience_models(params = {}) ⇒ Types::ListAudienceModelsResponse
Returns a list of audience models.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2780 2781 2782 2783 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2780 def list_audience_models(params = {}, = {}) req = build_request(:list_audience_models, params) req.send_request() end |
#list_collaboration_configured_model_algorithm_associations(params = {}) ⇒ Types::ListCollaborationConfiguredModelAlgorithmAssociationsResponse
Returns a list of the configured model algorithm associations in a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2832 2833 2834 2835 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2832 def list_collaboration_configured_model_algorithm_associations(params = {}, = {}) req = build_request(:list_collaboration_configured_model_algorithm_associations, params) req.send_request() end |
#list_collaboration_ml_input_channels(params = {}) ⇒ Types::ListCollaborationMLInputChannelsResponse
Returns a list of the ML input channels in a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2887 2888 2889 2890 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2887 def list_collaboration_ml_input_channels(params = {}, = {}) req = build_request(:list_collaboration_ml_input_channels, params) req.send_request() end |
#list_collaboration_trained_model_export_jobs(params = {}) ⇒ Types::ListCollaborationTrainedModelExportJobsResponse
Returns a list of the export jobs for a trained model in a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2955 2956 2957 2958 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 2955 def list_collaboration_trained_model_export_jobs(params = {}, = {}) req = build_request(:list_collaboration_trained_model_export_jobs, params) req.send_request() end |
#list_collaboration_trained_model_inference_jobs(params = {}) ⇒ Types::ListCollaborationTrainedModelInferenceJobsResponse
Returns a list of trained model inference jobs in a specified collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3029 3030 3031 3032 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3029 def list_collaboration_trained_model_inference_jobs(params = {}, = {}) req = build_request(:list_collaboration_trained_model_inference_jobs, params) req.send_request() end |
#list_collaboration_trained_models(params = {}) ⇒ Types::ListCollaborationTrainedModelsResponse
Returns a list of the trained models in a collaboration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3087 3088 3089 3090 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3087 def list_collaboration_trained_models(params = {}, = {}) req = build_request(:list_collaboration_trained_models, params) req.send_request() end |
#list_configured_audience_models(params = {}) ⇒ Types::ListConfiguredAudienceModelsResponse
Returns a list of the configured audience models.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3133 3134 3135 3136 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3133 def list_configured_audience_models(params = {}, = {}) req = build_request(:list_configured_audience_models, params) req.send_request() end |
#list_configured_model_algorithm_associations(params = {}) ⇒ Types::ListConfiguredModelAlgorithmAssociationsResponse
Returns a list of configured model algorithm associations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3183 3184 3185 3186 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3183 def list_configured_model_algorithm_associations(params = {}, = {}) req = build_request(:list_configured_model_algorithm_associations, params) req.send_request() end |
#list_configured_model_algorithms(params = {}) ⇒ Types::ListConfiguredModelAlgorithmsResponse
Returns a list of configured model algorithms.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3225 3226 3227 3228 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3225 def list_configured_model_algorithms(params = {}, = {}) req = build_request(:list_configured_model_algorithms, params) req.send_request() end |
#list_ml_input_channels(params = {}) ⇒ Types::ListMLInputChannelsResponse
Returns a list of ML input channels.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3280 3281 3282 3283 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3280 def list_ml_input_channels(params = {}, = {}) req = build_request(:list_ml_input_channels, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a provided resource.
3310 3311 3312 3313 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3310 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_trained_model_inference_jobs(params = {}) ⇒ Types::ListTrainedModelInferenceJobsResponse
Returns a list of trained model inference jobs that match the request parameters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3382 3383 3384 3385 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3382 def list_trained_model_inference_jobs(params = {}, = {}) req = build_request(:list_trained_model_inference_jobs, params) req.send_request() end |
#list_trained_model_versions(params = {}) ⇒ Types::ListTrainedModelVersionsResponse
Returns a list of trained model versions for a specified trained model. This operation allows you to view all versions of a trained model, including information about their status and creation details. You can use this to track the evolution of your trained models and select specific versions for inference or further training.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3455 3456 3457 3458 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3455 def list_trained_model_versions(params = {}, = {}) req = build_request(:list_trained_model_versions, params) req.send_request() end |
#list_trained_models(params = {}) ⇒ Types::ListTrainedModelsResponse
Returns a list of trained models.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3512 3513 3514 3515 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3512 def list_trained_models(params = {}, = {}) req = build_request(:list_trained_models, params) req.send_request() end |
#list_training_datasets(params = {}) ⇒ Types::ListTrainingDatasetsResponse
Returns a list of training datasets.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3555 3556 3557 3558 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3555 def list_training_datasets(params = {}, = {}) req = build_request(:list_training_datasets, params) req.send_request() end |
#put_configured_audience_model_policy(params = {}) ⇒ Types::PutConfiguredAudienceModelPolicyResponse
Create or update the resource policy for a configured audience model.
3599 3600 3601 3602 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3599 def put_configured_audience_model_policy(params = {}, = {}) req = build_request(:put_configured_audience_model_policy, params) req.send_request() end |
#put_ml_configuration(params = {}) ⇒ Struct
Assigns information about an ML configuration.
3633 3634 3635 3636 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3633 def put_ml_configuration(params = {}, = {}) req = build_request(:put_ml_configuration, params) req.send_request() end |
#start_audience_export_job(params = {}) ⇒ Struct
Export an audience of a specified size after you have generated an audience.
3673 3674 3675 3676 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3673 def start_audience_export_job(params = {}, = {}) req = build_request(:start_audience_export_job, params) req.send_request() end |
#start_audience_generation_job(params = {}) ⇒ Types::StartAudienceGenerationJobResponse
Information necessary to start the audience generation job.
3782 3783 3784 3785 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3782 def start_audience_generation_job(params = {}, = {}) req = build_request(:start_audience_generation_job, params) req.send_request() end |
#start_trained_model_export_job(params = {}) ⇒ Struct
Provides the information necessary to start a trained model export job.
3835 3836 3837 3838 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3835 def start_trained_model_export_job(params = {}, = {}) req = build_request(:start_trained_model_export_job, params) req.send_request() end |
#start_trained_model_inference_job(params = {}) ⇒ Types::StartTrainedModelInferenceJobResponse
Defines the information necessary to begin a trained model inference job.
3974 3975 3976 3977 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 3974 def start_trained_model_inference_job(params = {}, = {}) req = build_request(:start_trained_model_inference_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to a specified resource.
4032 4033 4034 4035 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 4032 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from a specified resource.
4059 4060 4061 4062 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 4059 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_configured_audience_model(params = {}) ⇒ Types::UpdateConfiguredAudienceModelResponse
Provides the information necessary to update a configured audience model. Updates that impact audience generation jobs take effect when a new job starts, but do not impact currently running jobs.
4126 4127 4128 4129 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 4126 def update_configured_audience_model(params = {}, = {}) req = build_request(:update_configured_audience_model, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4155 4156 4157 |
# File 'lib/aws-sdk-cleanroomsml/client.rb', line 4155 def waiter_names [] end |