Class: Aws::CleanRoomsML::Types::GetCollaborationMLInputChannelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::GetCollaborationMLInputChannelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#collaboration_identifier ⇒ String
The collaboration ID of the collaboration that contains the ML input channel.
-
#configured_model_algorithm_associations ⇒ Array<String>
The configured model algorithm associations that were used to create the ML input channel.
-
#create_time ⇒ Time
The time at which the ML input channel was created.
-
#creator_account_id ⇒ String
The account ID of the member who created the ML input channel.
-
#description ⇒ String
The description of the ML input channel.
-
#membership_identifier ⇒ String
The membership ID of the membership that contains the ML input channel.
-
#ml_input_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the ML input channel.
-
#name ⇒ String
The name of the ML input channel.
-
#number_of_records ⇒ Integer
The number of records in the ML input channel.
-
#privacy_budgets ⇒ Types::PrivacyBudgets
Returns the privacy budgets that control access to this Clean Rooms ML input channel.
-
#retention_in_days ⇒ Integer
The number of days to retain the data for the ML input channel.
-
#status ⇒ String
The status of the ML input channel.
-
#status_details ⇒ Types::StatusDetails
Details about the status of a resource.
-
#synthetic_data_configuration ⇒ Types::SyntheticDataConfiguration
The synthetic data configuration for this ML input channel, including parameters for generating privacy-preserving synthetic data and evaluation scores for measuring the privacy of the generated data.
-
#update_time ⇒ Time
The most recent time at which the ML input channel was updated.
Instance Attribute Details
#collaboration_identifier ⇒ String
The collaboration ID of the collaboration that contains the ML input channel.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#configured_model_algorithm_associations ⇒ Array<String>
The configured model algorithm associations that were used to create the ML input channel.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time at which the ML input channel was created.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#creator_account_id ⇒ String
The account ID of the member who created the ML input channel.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the ML input channel.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The membership ID of the membership that contains the ML input channel.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#ml_input_channel_arn ⇒ String
The Amazon Resource Name (ARN) of the ML input channel.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the ML input channel.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#number_of_records ⇒ Integer
The number of records in the ML input channel.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#privacy_budgets ⇒ Types::PrivacyBudgets
Returns the privacy budgets that control access to this Clean Rooms ML input channel. Use these budgets to monitor and limit resource consumption over specified time periods.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#retention_in_days ⇒ Integer
The number of days to retain the data for the ML input channel.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the ML input channel.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#status_details ⇒ Types::StatusDetails
Details about the status of a resource.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#synthetic_data_configuration ⇒ Types::SyntheticDataConfiguration
The synthetic data configuration for this ML input channel, including parameters for generating privacy-preserving synthetic data and evaluation scores for measuring the privacy of the generated data.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |
#update_time ⇒ Time
The most recent time at which the ML input channel was updated.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 2430 class GetCollaborationMLInputChannelResponse < Struct.new( :membership_identifier, :collaboration_identifier, :ml_input_channel_arn, :name, :configured_model_algorithm_associations, :status, :status_details, :retention_in_days, :number_of_records, :privacy_budgets, :description, :synthetic_data_configuration, :create_time, :update_time, :creator_account_id) SENSITIVE = [] include Aws::Structure end |