Class: Aws::CleanRoomsML::Types::GetTrainedModelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::GetTrainedModelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#membership_identifier ⇒ String
The membership ID of the member that created the trained model that you are interested in.
-
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model that you are interested in.
-
#version_identifier ⇒ String
The version identifier of the trained model to retrieve.
Instance Attribute Details
#membership_identifier ⇒ String
The membership ID of the member that created the trained model that you are interested in.
3401 3402 3403 3404 3405 3406 3407 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 3401 class GetTrainedModelRequest < Struct.new( :trained_model_arn, :membership_identifier, :version_identifier) SENSITIVE = [] include Aws::Structure end |
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model that you are interested in.
3401 3402 3403 3404 3405 3406 3407 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 3401 class GetTrainedModelRequest < Struct.new( :trained_model_arn, :membership_identifier, :version_identifier) SENSITIVE = [] include Aws::Structure end |
#version_identifier ⇒ String
The version identifier of the trained model to retrieve. If not specified, the operation returns information about the latest version of the trained model.
3401 3402 3403 3404 3405 3406 3407 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 3401 class GetTrainedModelRequest < Struct.new( :trained_model_arn, :membership_identifier, :version_identifier) SENSITIVE = [] include Aws::Structure end |