Class: Aws::CleanRoomsML::Types::ListTrainedModelVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::ListTrainedModelVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of trained model versions to return in a single page.
-
#membership_identifier ⇒ String
The membership identifier for the collaboration that contains the trained model.
-
#next_token ⇒ String
The pagination token from a previous
ListTrainedModelVersionsrequest. -
#status ⇒ String
Filter the results to only include trained model versions with the specified status.
-
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model for which to list versions.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of trained model versions to return in a single page. The default value is 10, and the maximum value is 100.
4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4450 class ListTrainedModelVersionsRequest < Struct.new( :next_token, :max_results, :membership_identifier, :trained_model_arn, :status) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The membership identifier for the collaboration that contains the trained model.
4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4450 class ListTrainedModelVersionsRequest < Struct.new( :next_token, :max_results, :membership_identifier, :trained_model_arn, :status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token from a previous ListTrainedModelVersions request. Use this token to retrieve the next page of results.
4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4450 class ListTrainedModelVersionsRequest < Struct.new( :next_token, :max_results, :membership_identifier, :trained_model_arn, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Filter the results to only include trained model versions with the specified status. Valid values include CREATE_PENDING, CREATE_IN_PROGRESS, ACTIVE, CREATE_FAILED, and others.
4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4450 class ListTrainedModelVersionsRequest < Struct.new( :next_token, :max_results, :membership_identifier, :trained_model_arn, :status) SENSITIVE = [] include Aws::Structure end |
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model for which to list versions.
4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 4450 class ListTrainedModelVersionsRequest < Struct.new( :next_token, :max_results, :membership_identifier, :trained_model_arn, :status) SENSITIVE = [] include Aws::Structure end |