Class: Aws::CleanRoomsML::Types::StartTrainedModelExportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::StartTrainedModelExportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the trained model export job.
-
#membership_identifier ⇒ String
The membership ID of the member that is receiving the exported trained model artifacts.
-
#name ⇒ String
The name of the trained model export job.
-
#output_configuration ⇒ Types::TrainedModelExportOutputConfiguration
The output configuration information for the trained model export job.
-
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model that you want to export.
-
#trained_model_version_identifier ⇒ String
The version identifier of the trained model to export.
Instance Attribute Details
#description ⇒ String
The description of the trained model export job.
5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5352 class StartTrainedModelExportJobRequest < Struct.new( :name, :trained_model_arn, :trained_model_version_identifier, :membership_identifier, :output_configuration, :description) SENSITIVE = [] include Aws::Structure end |
#membership_identifier ⇒ String
The membership ID of the member that is receiving the exported trained model artifacts.
5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5352 class StartTrainedModelExportJobRequest < Struct.new( :name, :trained_model_arn, :trained_model_version_identifier, :membership_identifier, :output_configuration, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the trained model export job.
5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5352 class StartTrainedModelExportJobRequest < Struct.new( :name, :trained_model_arn, :trained_model_version_identifier, :membership_identifier, :output_configuration, :description) SENSITIVE = [] include Aws::Structure end |
#output_configuration ⇒ Types::TrainedModelExportOutputConfiguration
The output configuration information for the trained model export job.
5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5352 class StartTrainedModelExportJobRequest < Struct.new( :name, :trained_model_arn, :trained_model_version_identifier, :membership_identifier, :output_configuration, :description) SENSITIVE = [] include Aws::Structure end |
#trained_model_arn ⇒ String
The Amazon Resource Name (ARN) of the trained model that you want to export.
5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5352 class StartTrainedModelExportJobRequest < Struct.new( :name, :trained_model_arn, :trained_model_version_identifier, :membership_identifier, :output_configuration, :description) SENSITIVE = [] include Aws::Structure end |
#trained_model_version_identifier ⇒ String
The version identifier of the trained model to export. This specifies which version of the trained model should be exported to the specified destination.
5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 5352 class StartTrainedModelExportJobRequest < Struct.new( :name, :trained_model_arn, :trained_model_version_identifier, :membership_identifier, :output_configuration, :description) SENSITIVE = [] include Aws::Structure end |