Class: Aws::CleanRoomsML::Types::WorkerComputeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::CleanRoomsML::Types::WorkerComputeConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cleanroomsml/types.rb
Overview
Configuration information about the compute workers that perform the transform job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#number ⇒ Integer
The number of compute workers that are used.
-
#properties ⇒ Types::WorkerComputeConfigurationProperties
The configuration properties for the worker compute environment.
-
#type ⇒ String
The instance type of the compute workers that are used.
Instance Attribute Details
#number ⇒ Integer
The number of compute workers that are used.
6055 6056 6057 6058 6059 6060 6061 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6055 class WorkerComputeConfiguration < Struct.new( :type, :number, :properties) SENSITIVE = [] include Aws::Structure end |
#properties ⇒ Types::WorkerComputeConfigurationProperties
The configuration properties for the worker compute environment. These properties allow you to customize the compute settings for your Clean Rooms workloads.
6055 6056 6057 6058 6059 6060 6061 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6055 class WorkerComputeConfiguration < Struct.new( :type, :number, :properties) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The instance type of the compute workers that are used.
6055 6056 6057 6058 6059 6060 6061 |
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6055 class WorkerComputeConfiguration < Struct.new( :type, :number, :properties) SENSITIVE = [] include Aws::Structure end |