Class: Aws::CleanRoomsML::Types::WorkerComputeConfigurationProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-cleanroomsml/types.rb

Overview

Note:

WorkerComputeConfigurationProperties is a union - when making an API calls you must set exactly one of the members.

Note:

WorkerComputeConfigurationProperties is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of WorkerComputeConfigurationProperties corresponding to the set member.

The configuration properties for the worker compute environment. These properties allow you to customize the compute settings for your Clean Rooms workloads.

Direct Known Subclasses

Spark, Unknown

Defined Under Namespace

Classes: Spark, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#sparkHash<String,String>

The Spark configuration properties for SQL workloads. This map contains key-value pairs that configure Apache Spark settings to optimize performance for your data processing jobs. You can specify up to 50 Spark properties, with each key being 1-200 characters and each value being 0-500 characters. These properties allow you to adjust compute capacity for large datasets and complex workloads.

Returns:

  • (Hash<String,String>)


6184
6185
6186
6187
6188
6189
6190
6191
6192
6193
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6184

class WorkerComputeConfigurationProperties < Struct.new(
  :spark,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Spark < WorkerComputeConfigurationProperties; end
  class Unknown < WorkerComputeConfigurationProperties; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



6184
6185
6186
# File 'lib/aws-sdk-cleanroomsml/types.rb', line 6184

def unknown
  @unknown
end